import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { ComputeManagementClientContext } from "../computeManagementClientContext";
/** Class representing a CloudServicesUpdateDomain. */
export declare class CloudServicesUpdateDomain {
    private readonly client;
    /**
     * Create a CloudServicesUpdateDomain.
     * @param {ComputeManagementClientContext} client Reference to the service client.
     */
    constructor(client: ComputeManagementClientContext);
    /**
     * Updates the role instances in the specified update domain.
     * @param resourceGroupName Name of the resource group.
     * @param cloudServiceName Name of the cloud service.
     * @param updateDomain Specifies an integer value that identifies the update domain. Update domains
     * are identified with a zero-based index: the first update domain has an ID of 0, the second has
     * an ID of 1, and so on.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    walkUpdateDomain(resourceGroupName: string, cloudServiceName: string, updateDomain: number, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Gets the specified update domain of a cloud service. Use nextLink property in the response to
     * get the next page of update domains. Do this till nextLink is null to fetch all the update
     * domains.
     * @param resourceGroupName Name of the resource group.
     * @param cloudServiceName Name of the cloud service.
     * @param updateDomain Specifies an integer value that identifies the update domain. Update domains
     * are identified with a zero-based index: the first update domain has an ID of 0, the second has
     * an ID of 1, and so on.
     * @param [options] The optional parameters
     * @returns Promise<Models.CloudServicesUpdateDomainGetUpdateDomainResponse>
     */
    getUpdateDomain(resourceGroupName: string, cloudServiceName: string, updateDomain: number, options?: msRest.RequestOptionsBase): Promise<Models.CloudServicesUpdateDomainGetUpdateDomainResponse>;
    /**
     * @param resourceGroupName Name of the resource group.
     * @param cloudServiceName Name of the cloud service.
     * @param updateDomain Specifies an integer value that identifies the update domain. Update domains
     * are identified with a zero-based index: the first update domain has an ID of 0, the second has
     * an ID of 1, and so on.
     * @param callback The callback
     */
    getUpdateDomain(resourceGroupName: string, cloudServiceName: string, updateDomain: number, callback: msRest.ServiceCallback<Models.UpdateDomain>): void;
    /**
     * @param resourceGroupName Name of the resource group.
     * @param cloudServiceName Name of the cloud service.
     * @param updateDomain Specifies an integer value that identifies the update domain. Update domains
     * are identified with a zero-based index: the first update domain has an ID of 0, the second has
     * an ID of 1, and so on.
     * @param options The optional parameters
     * @param callback The callback
     */
    getUpdateDomain(resourceGroupName: string, cloudServiceName: string, updateDomain: number, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.UpdateDomain>): void;
    /**
     * Gets a list of all update domains in a cloud service.
     * @param resourceGroupName Name of the resource group.
     * @param cloudServiceName Name of the cloud service.
     * @param [options] The optional parameters
     * @returns Promise<Models.CloudServicesUpdateDomainListUpdateDomainsResponse>
     */
    listUpdateDomains(resourceGroupName: string, cloudServiceName: string, options?: msRest.RequestOptionsBase): Promise<Models.CloudServicesUpdateDomainListUpdateDomainsResponse>;
    /**
     * @param resourceGroupName Name of the resource group.
     * @param cloudServiceName Name of the cloud service.
     * @param callback The callback
     */
    listUpdateDomains(resourceGroupName: string, cloudServiceName: string, callback: msRest.ServiceCallback<Models.UpdateDomainListResult>): void;
    /**
     * @param resourceGroupName Name of the resource group.
     * @param cloudServiceName Name of the cloud service.
     * @param options The optional parameters
     * @param callback The callback
     */
    listUpdateDomains(resourceGroupName: string, cloudServiceName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.UpdateDomainListResult>): void;
    /**
     * Updates the role instances in the specified update domain.
     * @param resourceGroupName Name of the resource group.
     * @param cloudServiceName Name of the cloud service.
     * @param updateDomain Specifies an integer value that identifies the update domain. Update domains
     * are identified with a zero-based index: the first update domain has an ID of 0, the second has
     * an ID of 1, and so on.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginWalkUpdateDomain(resourceGroupName: string, cloudServiceName: string, updateDomain: number, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Gets a list of all update domains in a cloud service.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.CloudServicesUpdateDomainListUpdateDomainsNextResponse>
     */
    listUpdateDomainsNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.CloudServicesUpdateDomainListUpdateDomainsNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listUpdateDomainsNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.UpdateDomainListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listUpdateDomainsNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.UpdateDomainListResult>): void;
}
//# sourceMappingURL=cloudServicesUpdateDomain.d.ts.map