import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { ComputeManagementClientContext } from "../computeManagementClientContext";
/** Class representing a DiskRestorePointOperations. */
export declare class DiskRestorePointOperations {
    private readonly client;
    /**
     * Create a DiskRestorePointOperations.
     * @param {ComputeManagementClientContext} client Reference to the service client.
     */
    constructor(client: ComputeManagementClientContext);
    /**
     * Get disk restorePoint resource
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs. Supported characters for the name are a-z, A-Z, 0-9 and _. The maximum name
     * length is 80 characters.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs. Supported characters for the name are a-z, A-Z, 0-9 and _. The maximum name length is
     * 80 characters.
     * @param diskRestorePointName The name of the disk restore point created. Supported characters for
     * the name are a-z, A-Z, 0-9 and _. The maximum name length is 80 characters.
     * @param [options] The optional parameters
     * @returns Promise<Models.DiskRestorePointGetResponse>
     */
    get(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, diskRestorePointName: string, options?: msRest.RequestOptionsBase): Promise<Models.DiskRestorePointGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs. Supported characters for the name are a-z, A-Z, 0-9 and _. The maximum name
     * length is 80 characters.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs. Supported characters for the name are a-z, A-Z, 0-9 and _. The maximum name length is
     * 80 characters.
     * @param diskRestorePointName The name of the disk restore point created. Supported characters for
     * the name are a-z, A-Z, 0-9 and _. The maximum name length is 80 characters.
     * @param callback The callback
     */
    get(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, diskRestorePointName: string, callback: msRest.ServiceCallback<Models.DiskRestorePoint>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs. Supported characters for the name are a-z, A-Z, 0-9 and _. The maximum name
     * length is 80 characters.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs. Supported characters for the name are a-z, A-Z, 0-9 and _. The maximum name length is
     * 80 characters.
     * @param diskRestorePointName The name of the disk restore point created. Supported characters for
     * the name are a-z, A-Z, 0-9 and _. The maximum name length is 80 characters.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, diskRestorePointName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DiskRestorePoint>): void;
    /**
     * Lists diskRestorePoints under a vmRestorePoint.
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs. Supported characters for the name are a-z, A-Z, 0-9 and _. The maximum name
     * length is 80 characters.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs. Supported characters for the name are a-z, A-Z, 0-9 and _. The maximum name length is
     * 80 characters.
     * @param [options] The optional parameters
     * @returns Promise<Models.DiskRestorePointListByRestorePointResponse>
     */
    listByRestorePoint(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, options?: msRest.RequestOptionsBase): Promise<Models.DiskRestorePointListByRestorePointResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs. Supported characters for the name are a-z, A-Z, 0-9 and _. The maximum name
     * length is 80 characters.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs. Supported characters for the name are a-z, A-Z, 0-9 and _. The maximum name length is
     * 80 characters.
     * @param callback The callback
     */
    listByRestorePoint(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, callback: msRest.ServiceCallback<Models.DiskRestorePointList>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param restorePointCollectionName The name of the restore point collection that the disk restore
     * point belongs. Supported characters for the name are a-z, A-Z, 0-9 and _. The maximum name
     * length is 80 characters.
     * @param vmRestorePointName The name of the vm restore point that the disk disk restore point
     * belongs. Supported characters for the name are a-z, A-Z, 0-9 and _. The maximum name length is
     * 80 characters.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByRestorePoint(resourceGroupName: string, restorePointCollectionName: string, vmRestorePointName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DiskRestorePointList>): void;
    /**
     * Lists diskRestorePoints under a vmRestorePoint.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.DiskRestorePointListByRestorePointNextResponse>
     */
    listByRestorePointNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.DiskRestorePointListByRestorePointNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByRestorePointNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.DiskRestorePointList>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByRestorePointNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.DiskRestorePointList>): void;
}
//# sourceMappingURL=diskRestorePointOperations.d.ts.map