/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import * as Mappers from "../models/virtualMachineScaleSetsMappers";
import * as Parameters from "../models/parameters";
import { ComputeManagementClientContext } from "../computeManagementClientContext";

/** Class representing a VirtualMachineScaleSets. */
export class VirtualMachineScaleSets {
  private readonly client: ComputeManagementClientContext;

  /**
   * Create a VirtualMachineScaleSets.
   * @param {ComputeManagementClientContext} client Reference to the service client.
   */
  constructor(client: ComputeManagementClientContext) {
    this.client = client;
  }

  /**
   * Gets all the VM scale sets under the specified subscription for the specified location.
   * @param location The location for which VM scale sets under the subscription are queried.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsListByLocationResponse>
   */
  listByLocation(
    location: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.VirtualMachineScaleSetsListByLocationResponse>;
  /**
   * @param location The location for which VM scale sets under the subscription are queried.
   * @param callback The callback
   */
  listByLocation(
    location: string,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>
  ): void;
  /**
   * @param location The location for which VM scale sets under the subscription are queried.
   * @param options The optional parameters
   * @param callback The callback
   */
  listByLocation(
    location: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>
  ): void;
  listByLocation(
    location: string,
    options?:
      | msRest.RequestOptionsBase
      | msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>,
    callback?: msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>
  ): Promise<Models.VirtualMachineScaleSetsListByLocationResponse> {
    return this.client.sendOperationRequest(
      {
        location,
        options
      },
      listByLocationOperationSpec,
      callback
    ) as Promise<Models.VirtualMachineScaleSetsListByLocationResponse>;
  }

  /**
   * Create or update a VM scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set to create or update.
   * @param parameters The scale set object.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsCreateOrUpdateResponse>
   */
  createOrUpdate(
    resourceGroupName: string,
    vmScaleSetName: string,
    parameters: Models.VirtualMachineScaleSet,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.VirtualMachineScaleSetsCreateOrUpdateResponse> {
    return this.beginCreateOrUpdate(
      resourceGroupName,
      vmScaleSetName,
      parameters,
      options
    ).then((lroPoller) => lroPoller.pollUntilFinished()) as Promise<
      Models.VirtualMachineScaleSetsCreateOrUpdateResponse
    >;
  }

  /**
   * Update a VM scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set to create or update.
   * @param parameters The scale set object.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsUpdateResponse>
   */
  update(
    resourceGroupName: string,
    vmScaleSetName: string,
    parameters: Models.VirtualMachineScaleSetUpdate,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.VirtualMachineScaleSetsUpdateResponse> {
    return this.beginUpdate(
      resourceGroupName,
      vmScaleSetName,
      parameters,
      options
    ).then((lroPoller) => lroPoller.pollUntilFinished()) as Promise<
      Models.VirtualMachineScaleSetsUpdateResponse
    >;
  }

  /**
   * Deletes a VM scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  deleteMethod(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsDeleteMethodOptionalParams
  ): Promise<msRest.RestResponse> {
    return this.beginDeleteMethod(resourceGroupName, vmScaleSetName, options).then((lroPoller) =>
      lroPoller.pollUntilFinished()
    );
  }

  /**
   * Display information about a virtual machine scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsGetResponse>
   */
  get(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsGetOptionalParams
  ): Promise<Models.VirtualMachineScaleSetsGetResponse>;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param callback The callback
   */
  get(
    resourceGroupName: string,
    vmScaleSetName: string,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSet>
  ): void;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param options The optional parameters
   * @param callback The callback
   */
  get(
    resourceGroupName: string,
    vmScaleSetName: string,
    options: Models.VirtualMachineScaleSetsGetOptionalParams,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSet>
  ): void;
  get(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?:
      | Models.VirtualMachineScaleSetsGetOptionalParams
      | msRest.ServiceCallback<Models.VirtualMachineScaleSet>,
    callback?: msRest.ServiceCallback<Models.VirtualMachineScaleSet>
  ): Promise<Models.VirtualMachineScaleSetsGetResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        vmScaleSetName,
        options
      },
      getOperationSpec,
      callback
    ) as Promise<Models.VirtualMachineScaleSetsGetResponse>;
  }

  /**
   * Deallocates specific virtual machines in a VM scale set. Shuts down the virtual machines and
   * releases the compute resources. You are not billed for the compute resources that this virtual
   * machine scale set deallocates.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  deallocate(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsDeallocateOptionalParams
  ): Promise<msRest.RestResponse> {
    return this.beginDeallocate(resourceGroupName, vmScaleSetName, options).then((lroPoller) =>
      lroPoller.pollUntilFinished()
    );
  }

  /**
   * Deletes virtual machines in a VM scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param vmInstanceIDs A list of virtual machine instance IDs from the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  deleteInstances(
    resourceGroupName: string,
    vmScaleSetName: string,
    vmInstanceIDs: Models.VirtualMachineScaleSetVMInstanceRequiredIDs,
    options?: Models.VirtualMachineScaleSetsDeleteInstancesOptionalParams
  ): Promise<msRest.RestResponse> {
    return this.beginDeleteInstances(
      resourceGroupName,
      vmScaleSetName,
      vmInstanceIDs,
      options
    ).then((lroPoller) => lroPoller.pollUntilFinished());
  }

  /**
   * Gets the status of a VM scale set instance.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsGetInstanceViewResponse>
   */
  getInstanceView(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.VirtualMachineScaleSetsGetInstanceViewResponse>;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param callback The callback
   */
  getInstanceView(
    resourceGroupName: string,
    vmScaleSetName: string,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetInstanceView>
  ): void;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param options The optional parameters
   * @param callback The callback
   */
  getInstanceView(
    resourceGroupName: string,
    vmScaleSetName: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetInstanceView>
  ): void;
  getInstanceView(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?:
      | msRest.RequestOptionsBase
      | msRest.ServiceCallback<Models.VirtualMachineScaleSetInstanceView>,
    callback?: msRest.ServiceCallback<Models.VirtualMachineScaleSetInstanceView>
  ): Promise<Models.VirtualMachineScaleSetsGetInstanceViewResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        vmScaleSetName,
        options
      },
      getInstanceViewOperationSpec,
      callback
    ) as Promise<Models.VirtualMachineScaleSetsGetInstanceViewResponse>;
  }

  /**
   * Gets a list of all VM scale sets under a resource group.
   * @param resourceGroupName The name of the resource group.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsListResponse>
   */
  list(
    resourceGroupName: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.VirtualMachineScaleSetsListResponse>;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param callback The callback
   */
  list(
    resourceGroupName: string,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>
  ): void;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param options The optional parameters
   * @param callback The callback
   */
  list(
    resourceGroupName: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>
  ): void;
  list(
    resourceGroupName: string,
    options?:
      | msRest.RequestOptionsBase
      | msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>,
    callback?: msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>
  ): Promise<Models.VirtualMachineScaleSetsListResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        options
      },
      listOperationSpec,
      callback
    ) as Promise<Models.VirtualMachineScaleSetsListResponse>;
  }

  /**
   * Gets a list of all VM Scale Sets in the subscription, regardless of the associated resource
   * group. Use nextLink property in the response to get the next page of VM Scale Sets. Do this till
   * nextLink is null to fetch all the VM Scale Sets.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsListAllResponse>
   */
  listAll(
    options?: msRest.RequestOptionsBase
  ): Promise<Models.VirtualMachineScaleSetsListAllResponse>;
  /**
   * @param callback The callback
   */
  listAll(callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListWithLinkResult>): void;
  /**
   * @param options The optional parameters
   * @param callback The callback
   */
  listAll(
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListWithLinkResult>
  ): void;
  listAll(
    options?:
      | msRest.RequestOptionsBase
      | msRest.ServiceCallback<Models.VirtualMachineScaleSetListWithLinkResult>,
    callback?: msRest.ServiceCallback<Models.VirtualMachineScaleSetListWithLinkResult>
  ): Promise<Models.VirtualMachineScaleSetsListAllResponse> {
    return this.client.sendOperationRequest(
      {
        options
      },
      listAllOperationSpec,
      callback
    ) as Promise<Models.VirtualMachineScaleSetsListAllResponse>;
  }

  /**
   * Gets a list of SKUs available for your VM scale set, including the minimum and maximum VM
   * instances allowed for each SKU.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsListSkusResponse>
   */
  listSkus(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.VirtualMachineScaleSetsListSkusResponse>;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param callback The callback
   */
  listSkus(
    resourceGroupName: string,
    vmScaleSetName: string,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListSkusResult>
  ): void;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param options The optional parameters
   * @param callback The callback
   */
  listSkus(
    resourceGroupName: string,
    vmScaleSetName: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListSkusResult>
  ): void;
  listSkus(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?:
      | msRest.RequestOptionsBase
      | msRest.ServiceCallback<Models.VirtualMachineScaleSetListSkusResult>,
    callback?: msRest.ServiceCallback<Models.VirtualMachineScaleSetListSkusResult>
  ): Promise<Models.VirtualMachineScaleSetsListSkusResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        vmScaleSetName,
        options
      },
      listSkusOperationSpec,
      callback
    ) as Promise<Models.VirtualMachineScaleSetsListSkusResponse>;
  }

  /**
   * Gets list of OS upgrades on a VM scale set instance.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsGetOSUpgradeHistoryResponse>
   */
  getOSUpgradeHistory(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.VirtualMachineScaleSetsGetOSUpgradeHistoryResponse>;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param callback The callback
   */
  getOSUpgradeHistory(
    resourceGroupName: string,
    vmScaleSetName: string,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListOSUpgradeHistory>
  ): void;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param options The optional parameters
   * @param callback The callback
   */
  getOSUpgradeHistory(
    resourceGroupName: string,
    vmScaleSetName: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListOSUpgradeHistory>
  ): void;
  getOSUpgradeHistory(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?:
      | msRest.RequestOptionsBase
      | msRest.ServiceCallback<Models.VirtualMachineScaleSetListOSUpgradeHistory>,
    callback?: msRest.ServiceCallback<Models.VirtualMachineScaleSetListOSUpgradeHistory>
  ): Promise<Models.VirtualMachineScaleSetsGetOSUpgradeHistoryResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        vmScaleSetName,
        options
      },
      getOSUpgradeHistoryOperationSpec,
      callback
    ) as Promise<Models.VirtualMachineScaleSetsGetOSUpgradeHistoryResponse>;
  }

  /**
   * Power off (stop) one or more virtual machines in a VM scale set. Note that resources are still
   * attached and you are getting charged for the resources. Instead, use deallocate to release
   * resources and avoid charges.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  powerOff(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsPowerOffOptionalParams
  ): Promise<msRest.RestResponse> {
    return this.beginPowerOff(resourceGroupName, vmScaleSetName, options).then((lroPoller) =>
      lroPoller.pollUntilFinished()
    );
  }

  /**
   * Restarts one or more virtual machines in a VM scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  restart(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsRestartOptionalParams
  ): Promise<msRest.RestResponse> {
    return this.beginRestart(resourceGroupName, vmScaleSetName, options).then((lroPoller) =>
      lroPoller.pollUntilFinished()
    );
  }

  /**
   * Starts one or more virtual machines in a VM scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  start(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsStartOptionalParams
  ): Promise<msRest.RestResponse> {
    return this.beginStart(resourceGroupName, vmScaleSetName, options).then((lroPoller) =>
      lroPoller.pollUntilFinished()
    );
  }

  /**
   * Shuts down all the virtual machines in the virtual machine scale set, moves them to a new node,
   * and powers them back on.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  redeploy(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsRedeployOptionalParams
  ): Promise<msRest.RestResponse> {
    return this.beginRedeploy(resourceGroupName, vmScaleSetName, options).then((lroPoller) =>
      lroPoller.pollUntilFinished()
    );
  }

  /**
   * Perform maintenance on one or more virtual machines in a VM scale set. Operation on instances
   * which are not eligible for perform maintenance will be failed. Please refer to best practices
   * for more details:
   * https://docs.microsoft.com/azure/virtual-machine-scale-sets/virtual-machine-scale-sets-maintenance-notifications
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  performMaintenance(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsPerformMaintenanceOptionalParams
  ): Promise<msRest.RestResponse> {
    return this.beginPerformMaintenance(
      resourceGroupName,
      vmScaleSetName,
      options
    ).then((lroPoller) => lroPoller.pollUntilFinished());
  }

  /**
   * Upgrades one or more virtual machines to the latest SKU set in the VM scale set model.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param vmInstanceIDs A list of virtual machine instance IDs from the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  updateInstances(
    resourceGroupName: string,
    vmScaleSetName: string,
    vmInstanceIDs: Models.VirtualMachineScaleSetVMInstanceRequiredIDs,
    options?: msRest.RequestOptionsBase
  ): Promise<msRest.RestResponse> {
    return this.beginUpdateInstances(
      resourceGroupName,
      vmScaleSetName,
      vmInstanceIDs,
      options
    ).then((lroPoller) => lroPoller.pollUntilFinished());
  }

  /**
   * Reimages (upgrade the operating system) one or more virtual machines in a VM scale set which
   * don't have a ephemeral OS disk, for virtual machines who have a ephemeral OS disk the virtual
   * machine is reset to initial state.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  reimage(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsReimageOptionalParams
  ): Promise<msRest.RestResponse> {
    return this.beginReimage(resourceGroupName, vmScaleSetName, options).then((lroPoller) =>
      lroPoller.pollUntilFinished()
    );
  }

  /**
   * Reimages all the disks ( including data disks ) in the virtual machines in a VM scale set. This
   * operation is only supported for managed disks.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  reimageAll(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsReimageAllOptionalParams
  ): Promise<msRest.RestResponse> {
    return this.beginReimageAll(resourceGroupName, vmScaleSetName, options).then((lroPoller) =>
      lroPoller.pollUntilFinished()
    );
  }

  /**
   * Manual platform update domain walk to update virtual machines in a service fabric virtual
   * machine scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param platformUpdateDomain The platform update domain for which a manual recovery walk is
   * requested
   * @param [options] The optional parameters
   * @returns
   * Promise<Models.VirtualMachineScaleSetsForceRecoveryServiceFabricPlatformUpdateDomainWalkResponse>
   */
  forceRecoveryServiceFabricPlatformUpdateDomainWalk(
    resourceGroupName: string,
    vmScaleSetName: string,
    platformUpdateDomain: number,
    options?: msRest.RequestOptionsBase
  ): Promise<
    Models.VirtualMachineScaleSetsForceRecoveryServiceFabricPlatformUpdateDomainWalkResponse
  >;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param platformUpdateDomain The platform update domain for which a manual recovery walk is
   * requested
   * @param callback The callback
   */
  forceRecoveryServiceFabricPlatformUpdateDomainWalk(
    resourceGroupName: string,
    vmScaleSetName: string,
    platformUpdateDomain: number,
    callback: msRest.ServiceCallback<Models.RecoveryWalkResponse>
  ): void;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param platformUpdateDomain The platform update domain for which a manual recovery walk is
   * requested
   * @param options The optional parameters
   * @param callback The callback
   */
  forceRecoveryServiceFabricPlatformUpdateDomainWalk(
    resourceGroupName: string,
    vmScaleSetName: string,
    platformUpdateDomain: number,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.RecoveryWalkResponse>
  ): void;
  forceRecoveryServiceFabricPlatformUpdateDomainWalk(
    resourceGroupName: string,
    vmScaleSetName: string,
    platformUpdateDomain: number,
    options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.RecoveryWalkResponse>,
    callback?: msRest.ServiceCallback<Models.RecoveryWalkResponse>
  ): Promise<
    Models.VirtualMachineScaleSetsForceRecoveryServiceFabricPlatformUpdateDomainWalkResponse
  > {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        vmScaleSetName,
        platformUpdateDomain,
        options
      },
      forceRecoveryServiceFabricPlatformUpdateDomainWalkOperationSpec,
      callback
    ) as Promise<
      Models.VirtualMachineScaleSetsForceRecoveryServiceFabricPlatformUpdateDomainWalkResponse
    >;
  }

  /**
   * Converts SinglePlacementGroup property to false for a existing virtual machine scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the virtual machine scale set to create or update.
   * @param parameters The input object for ConvertToSinglePlacementGroup API.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  convertToSinglePlacementGroup(
    resourceGroupName: string,
    vmScaleSetName: string,
    parameters: Models.VMScaleSetConvertToSinglePlacementGroupInput,
    options?: msRest.RequestOptionsBase
  ): Promise<msRest.RestResponse>;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the virtual machine scale set to create or update.
   * @param parameters The input object for ConvertToSinglePlacementGroup API.
   * @param callback The callback
   */
  convertToSinglePlacementGroup(
    resourceGroupName: string,
    vmScaleSetName: string,
    parameters: Models.VMScaleSetConvertToSinglePlacementGroupInput,
    callback: msRest.ServiceCallback<void>
  ): void;
  /**
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the virtual machine scale set to create or update.
   * @param parameters The input object for ConvertToSinglePlacementGroup API.
   * @param options The optional parameters
   * @param callback The callback
   */
  convertToSinglePlacementGroup(
    resourceGroupName: string,
    vmScaleSetName: string,
    parameters: Models.VMScaleSetConvertToSinglePlacementGroupInput,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<void>
  ): void;
  convertToSinglePlacementGroup(
    resourceGroupName: string,
    vmScaleSetName: string,
    parameters: Models.VMScaleSetConvertToSinglePlacementGroupInput,
    options?: msRest.RequestOptionsBase | msRest.ServiceCallback<void>,
    callback?: msRest.ServiceCallback<void>
  ): Promise<msRest.RestResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        vmScaleSetName,
        parameters,
        options
      },
      convertToSinglePlacementGroupOperationSpec,
      callback
    );
  }

  /**
   * Changes ServiceState property for a given service
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the virtual machine scale set to create or update.
   * @param parameters The input object for SetOrchestrationServiceState API.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  setOrchestrationServiceState(
    resourceGroupName: string,
    vmScaleSetName: string,
    parameters: Models.OrchestrationServiceStateInput,
    options?: msRest.RequestOptionsBase
  ): Promise<msRest.RestResponse> {
    return this.beginSetOrchestrationServiceState(
      resourceGroupName,
      vmScaleSetName,
      parameters,
      options
    ).then((lroPoller) => lroPoller.pollUntilFinished());
  }

  /**
   * Create or update a VM scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set to create or update.
   * @param parameters The scale set object.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginCreateOrUpdate(
    resourceGroupName: string,
    vmScaleSetName: string,
    parameters: Models.VirtualMachineScaleSet,
    options?: msRest.RequestOptionsBase
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        parameters,
        options
      },
      beginCreateOrUpdateOperationSpec,
      options
    );
  }

  /**
   * Update a VM scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set to create or update.
   * @param parameters The scale set object.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginUpdate(
    resourceGroupName: string,
    vmScaleSetName: string,
    parameters: Models.VirtualMachineScaleSetUpdate,
    options?: msRest.RequestOptionsBase
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        parameters,
        options
      },
      beginUpdateOperationSpec,
      options
    );
  }

  /**
   * Deletes a VM scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginDeleteMethod(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsBeginDeleteMethodOptionalParams
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        options
      },
      beginDeleteMethodOperationSpec,
      options
    );
  }

  /**
   * Deallocates specific virtual machines in a VM scale set. Shuts down the virtual machines and
   * releases the compute resources. You are not billed for the compute resources that this virtual
   * machine scale set deallocates.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginDeallocate(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsBeginDeallocateOptionalParams
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        options
      },
      beginDeallocateOperationSpec,
      options
    );
  }

  /**
   * Deletes virtual machines in a VM scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param vmInstanceIDs A list of virtual machine instance IDs from the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginDeleteInstances(
    resourceGroupName: string,
    vmScaleSetName: string,
    vmInstanceIDs: Models.VirtualMachineScaleSetVMInstanceRequiredIDs,
    options?: Models.VirtualMachineScaleSetsBeginDeleteInstancesOptionalParams
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        vmInstanceIDs,
        options
      },
      beginDeleteInstancesOperationSpec,
      options
    );
  }

  /**
   * Power off (stop) one or more virtual machines in a VM scale set. Note that resources are still
   * attached and you are getting charged for the resources. Instead, use deallocate to release
   * resources and avoid charges.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginPowerOff(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsBeginPowerOffOptionalParams
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        options
      },
      beginPowerOffOperationSpec,
      options
    );
  }

  /**
   * Restarts one or more virtual machines in a VM scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginRestart(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsBeginRestartOptionalParams
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        options
      },
      beginRestartOperationSpec,
      options
    );
  }

  /**
   * Starts one or more virtual machines in a VM scale set.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginStart(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsBeginStartOptionalParams
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        options
      },
      beginStartOperationSpec,
      options
    );
  }

  /**
   * Shuts down all the virtual machines in the virtual machine scale set, moves them to a new node,
   * and powers them back on.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginRedeploy(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsBeginRedeployOptionalParams
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        options
      },
      beginRedeployOperationSpec,
      options
    );
  }

  /**
   * Perform maintenance on one or more virtual machines in a VM scale set. Operation on instances
   * which are not eligible for perform maintenance will be failed. Please refer to best practices
   * for more details:
   * https://docs.microsoft.com/azure/virtual-machine-scale-sets/virtual-machine-scale-sets-maintenance-notifications
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginPerformMaintenance(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsBeginPerformMaintenanceOptionalParams
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        options
      },
      beginPerformMaintenanceOperationSpec,
      options
    );
  }

  /**
   * Upgrades one or more virtual machines to the latest SKU set in the VM scale set model.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param vmInstanceIDs A list of virtual machine instance IDs from the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginUpdateInstances(
    resourceGroupName: string,
    vmScaleSetName: string,
    vmInstanceIDs: Models.VirtualMachineScaleSetVMInstanceRequiredIDs,
    options?: msRest.RequestOptionsBase
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        vmInstanceIDs,
        options
      },
      beginUpdateInstancesOperationSpec,
      options
    );
  }

  /**
   * Reimages (upgrade the operating system) one or more virtual machines in a VM scale set which
   * don't have a ephemeral OS disk, for virtual machines who have a ephemeral OS disk the virtual
   * machine is reset to initial state.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginReimage(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsBeginReimageOptionalParams
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        options
      },
      beginReimageOperationSpec,
      options
    );
  }

  /**
   * Reimages all the disks ( including data disks ) in the virtual machines in a VM scale set. This
   * operation is only supported for managed disks.
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the VM scale set.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginReimageAll(
    resourceGroupName: string,
    vmScaleSetName: string,
    options?: Models.VirtualMachineScaleSetsBeginReimageAllOptionalParams
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        options
      },
      beginReimageAllOperationSpec,
      options
    );
  }

  /**
   * Changes ServiceState property for a given service
   * @param resourceGroupName The name of the resource group.
   * @param vmScaleSetName The name of the virtual machine scale set to create or update.
   * @param parameters The input object for SetOrchestrationServiceState API.
   * @param [options] The optional parameters
   * @returns Promise<msRestAzure.LROPoller>
   */
  beginSetOrchestrationServiceState(
    resourceGroupName: string,
    vmScaleSetName: string,
    parameters: Models.OrchestrationServiceStateInput,
    options?: msRest.RequestOptionsBase
  ): Promise<msRestAzure.LROPoller> {
    return this.client.sendLRORequest(
      {
        resourceGroupName,
        vmScaleSetName,
        parameters,
        options
      },
      beginSetOrchestrationServiceStateOperationSpec,
      options
    );
  }

  /**
   * Gets all the VM scale sets under the specified subscription for the specified location.
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsListByLocationNextResponse>
   */
  listByLocationNext(
    nextPageLink: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.VirtualMachineScaleSetsListByLocationNextResponse>;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param callback The callback
   */
  listByLocationNext(
    nextPageLink: string,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>
  ): void;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  listByLocationNext(
    nextPageLink: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>
  ): void;
  listByLocationNext(
    nextPageLink: string,
    options?:
      | msRest.RequestOptionsBase
      | msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>,
    callback?: msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>
  ): Promise<Models.VirtualMachineScaleSetsListByLocationNextResponse> {
    return this.client.sendOperationRequest(
      {
        nextPageLink,
        options
      },
      listByLocationNextOperationSpec,
      callback
    ) as Promise<Models.VirtualMachineScaleSetsListByLocationNextResponse>;
  }

  /**
   * Gets a list of all VM scale sets under a resource group.
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsListNextResponse>
   */
  listNext(
    nextPageLink: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.VirtualMachineScaleSetsListNextResponse>;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param callback The callback
   */
  listNext(
    nextPageLink: string,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>
  ): void;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  listNext(
    nextPageLink: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>
  ): void;
  listNext(
    nextPageLink: string,
    options?:
      | msRest.RequestOptionsBase
      | msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>,
    callback?: msRest.ServiceCallback<Models.VirtualMachineScaleSetListResult>
  ): Promise<Models.VirtualMachineScaleSetsListNextResponse> {
    return this.client.sendOperationRequest(
      {
        nextPageLink,
        options
      },
      listNextOperationSpec,
      callback
    ) as Promise<Models.VirtualMachineScaleSetsListNextResponse>;
  }

  /**
   * Gets a list of all VM Scale Sets in the subscription, regardless of the associated resource
   * group. Use nextLink property in the response to get the next page of VM Scale Sets. Do this till
   * nextLink is null to fetch all the VM Scale Sets.
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsListAllNextResponse>
   */
  listAllNext(
    nextPageLink: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.VirtualMachineScaleSetsListAllNextResponse>;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param callback The callback
   */
  listAllNext(
    nextPageLink: string,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListWithLinkResult>
  ): void;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  listAllNext(
    nextPageLink: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListWithLinkResult>
  ): void;
  listAllNext(
    nextPageLink: string,
    options?:
      | msRest.RequestOptionsBase
      | msRest.ServiceCallback<Models.VirtualMachineScaleSetListWithLinkResult>,
    callback?: msRest.ServiceCallback<Models.VirtualMachineScaleSetListWithLinkResult>
  ): Promise<Models.VirtualMachineScaleSetsListAllNextResponse> {
    return this.client.sendOperationRequest(
      {
        nextPageLink,
        options
      },
      listAllNextOperationSpec,
      callback
    ) as Promise<Models.VirtualMachineScaleSetsListAllNextResponse>;
  }

  /**
   * Gets a list of SKUs available for your VM scale set, including the minimum and maximum VM
   * instances allowed for each SKU.
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsListSkusNextResponse>
   */
  listSkusNext(
    nextPageLink: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.VirtualMachineScaleSetsListSkusNextResponse>;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param callback The callback
   */
  listSkusNext(
    nextPageLink: string,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListSkusResult>
  ): void;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  listSkusNext(
    nextPageLink: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListSkusResult>
  ): void;
  listSkusNext(
    nextPageLink: string,
    options?:
      | msRest.RequestOptionsBase
      | msRest.ServiceCallback<Models.VirtualMachineScaleSetListSkusResult>,
    callback?: msRest.ServiceCallback<Models.VirtualMachineScaleSetListSkusResult>
  ): Promise<Models.VirtualMachineScaleSetsListSkusNextResponse> {
    return this.client.sendOperationRequest(
      {
        nextPageLink,
        options
      },
      listSkusNextOperationSpec,
      callback
    ) as Promise<Models.VirtualMachineScaleSetsListSkusNextResponse>;
  }

  /**
   * Gets list of OS upgrades on a VM scale set instance.
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.VirtualMachineScaleSetsGetOSUpgradeHistoryNextResponse>
   */
  getOSUpgradeHistoryNext(
    nextPageLink: string,
    options?: msRest.RequestOptionsBase
  ): Promise<Models.VirtualMachineScaleSetsGetOSUpgradeHistoryNextResponse>;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param callback The callback
   */
  getOSUpgradeHistoryNext(
    nextPageLink: string,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListOSUpgradeHistory>
  ): void;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  getOSUpgradeHistoryNext(
    nextPageLink: string,
    options: msRest.RequestOptionsBase,
    callback: msRest.ServiceCallback<Models.VirtualMachineScaleSetListOSUpgradeHistory>
  ): void;
  getOSUpgradeHistoryNext(
    nextPageLink: string,
    options?:
      | msRest.RequestOptionsBase
      | msRest.ServiceCallback<Models.VirtualMachineScaleSetListOSUpgradeHistory>,
    callback?: msRest.ServiceCallback<Models.VirtualMachineScaleSetListOSUpgradeHistory>
  ): Promise<Models.VirtualMachineScaleSetsGetOSUpgradeHistoryNextResponse> {
    return this.client.sendOperationRequest(
      {
        nextPageLink,
        options
      },
      getOSUpgradeHistoryNextOperationSpec,
      callback
    ) as Promise<Models.VirtualMachineScaleSetsGetOSUpgradeHistoryNextResponse>;
  }
}

// Operation Specifications
const serializer = new msRest.Serializer(Mappers);
const listByLocationOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path:
    "subscriptions/{subscriptionId}/providers/Microsoft.Compute/locations/{location}/virtualMachineScaleSets",
  urlParameters: [Parameters.location1, Parameters.subscriptionId],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSetListResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const getOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0, Parameters.expand0],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSet
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const getInstanceViewOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/instanceView",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSetInstanceView
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets",
  urlParameters: [Parameters.resourceGroupName, Parameters.subscriptionId],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSetListResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listAllOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "subscriptions/{subscriptionId}/providers/Microsoft.Compute/virtualMachineScaleSets",
  urlParameters: [Parameters.subscriptionId],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSetListWithLinkResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listSkusOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/skus",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSetListSkusResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const getOSUpgradeHistoryOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/osUpgradeHistory",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSetListOSUpgradeHistory
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const forceRecoveryServiceFabricPlatformUpdateDomainWalkOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/forceRecoveryServiceFabricPlatformUpdateDomainWalk",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0, Parameters.platformUpdateDomain],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.RecoveryWalkResponse
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const convertToSinglePlacementGroupOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/convertToSinglePlacementGroup",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: "parameters",
    mapper: {
      ...Mappers.VMScaleSetConvertToSinglePlacementGroupInput,
      required: true
    }
  },
  responses: {
    200: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginCreateOrUpdateOperationSpec: msRest.OperationSpec = {
  httpMethod: "PUT",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: "parameters",
    mapper: {
      ...Mappers.VirtualMachineScaleSet,
      required: true
    }
  },
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSet
    },
    201: {
      bodyMapper: Mappers.VirtualMachineScaleSet
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginUpdateOperationSpec: msRest.OperationSpec = {
  httpMethod: "PATCH",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: "parameters",
    mapper: {
      ...Mappers.VirtualMachineScaleSetUpdate,
      required: true
    }
  },
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSet
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginDeleteMethodOperationSpec: msRest.OperationSpec = {
  httpMethod: "DELETE",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.forceDeletion, Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {},
    202: {},
    204: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginDeallocateOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/deallocate",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: ["options", "vmInstanceIDs"],
    mapper: Mappers.VirtualMachineScaleSetVMInstanceIDs
  },
  responses: {
    200: {},
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginDeleteInstancesOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/delete",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.forceDeletion, Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: "vmInstanceIDs",
    mapper: {
      ...Mappers.VirtualMachineScaleSetVMInstanceRequiredIDs,
      required: true
    }
  },
  responses: {
    200: {},
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginPowerOffOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/poweroff",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.skipShutdown, Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: ["options", "vmInstanceIDs"],
    mapper: Mappers.VirtualMachineScaleSetVMInstanceIDs
  },
  responses: {
    200: {},
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginRestartOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/restart",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: ["options", "vmInstanceIDs"],
    mapper: Mappers.VirtualMachineScaleSetVMInstanceIDs
  },
  responses: {
    200: {},
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginStartOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/start",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: ["options", "vmInstanceIDs"],
    mapper: Mappers.VirtualMachineScaleSetVMInstanceIDs
  },
  responses: {
    200: {},
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginRedeployOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/redeploy",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: ["options", "vmInstanceIDs"],
    mapper: Mappers.VirtualMachineScaleSetVMInstanceIDs
  },
  responses: {
    200: {},
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginPerformMaintenanceOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/performMaintenance",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: ["options", "vmInstanceIDs"],
    mapper: Mappers.VirtualMachineScaleSetVMInstanceIDs
  },
  responses: {
    200: {},
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginUpdateInstancesOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/manualupgrade",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: "vmInstanceIDs",
    mapper: {
      ...Mappers.VirtualMachineScaleSetVMInstanceRequiredIDs,
      required: true
    }
  },
  responses: {
    200: {},
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginReimageOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/reimage",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: ["options", "vmScaleSetReimageInput"],
    mapper: Mappers.VirtualMachineScaleSetReimageParameters
  },
  responses: {
    200: {},
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginReimageAllOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/reimageall",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: ["options", "vmInstanceIDs"],
    mapper: Mappers.VirtualMachineScaleSetVMInstanceIDs
  },
  responses: {
    200: {},
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const beginSetOrchestrationServiceStateOperationSpec: msRest.OperationSpec = {
  httpMethod: "POST",
  path:
    "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmScaleSetName}/setOrchestrationServiceState",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.vmScaleSetName,
    Parameters.subscriptionId
  ],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  requestBody: {
    parameterPath: "parameters",
    mapper: {
      ...Mappers.OrchestrationServiceStateInput,
      required: true
    }
  },
  responses: {
    200: {},
    202: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listByLocationNextOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  baseUrl: "https://management.azure.com",
  path: "{nextLink}",
  urlParameters: [Parameters.nextPageLink],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSetListResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listNextOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  baseUrl: "https://management.azure.com",
  path: "{nextLink}",
  urlParameters: [Parameters.nextPageLink],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSetListResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listAllNextOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  baseUrl: "https://management.azure.com",
  path: "{nextLink}",
  urlParameters: [Parameters.nextPageLink],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSetListWithLinkResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listSkusNextOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  baseUrl: "https://management.azure.com",
  path: "{nextLink}",
  urlParameters: [Parameters.nextPageLink],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSetListSkusResult
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const getOSUpgradeHistoryNextOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  baseUrl: "https://management.azure.com",
  path: "{nextLink}",
  urlParameters: [Parameters.nextPageLink],
  queryParameters: [Parameters.apiVersion0],
  headerParameters: [Parameters.acceptLanguage],
  responses: {
    200: {
      bodyMapper: Mappers.VirtualMachineScaleSetListOSUpgradeHistory
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};
