import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a ApplicationGatewayPrivateEndpointConnections. */
export declare class ApplicationGatewayPrivateEndpointConnections {
    private readonly client;
    /**
     * Create a ApplicationGatewayPrivateEndpointConnections.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Deletes the specified private endpoint connection on application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param connectionName The name of the application gateway private endpoint connection.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, applicationGatewayName: string, connectionName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Updates the specified private endpoint connection on application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param connectionName The name of the application gateway private endpoint connection.
     * @param parameters Parameters supplied to update application gateway private endpoint connection
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ApplicationGatewayPrivateEndpointConnectionsUpdateResponse>
     */
    update(resourceGroupName: string, applicationGatewayName: string, connectionName: string, parameters: Models.ApplicationGatewayPrivateEndpointConnection, options?: msRest.RequestOptionsBase): Promise<Models.ApplicationGatewayPrivateEndpointConnectionsUpdateResponse>;
    /**
     * Gets the specified private endpoint connection on application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param connectionName The name of the application gateway private endpoint connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.ApplicationGatewayPrivateEndpointConnectionsGetResponse>
     */
    get(resourceGroupName: string, applicationGatewayName: string, connectionName: string, options?: msRest.RequestOptionsBase): Promise<Models.ApplicationGatewayPrivateEndpointConnectionsGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param connectionName The name of the application gateway private endpoint connection.
     * @param callback The callback
     */
    get(resourceGroupName: string, applicationGatewayName: string, connectionName: string, callback: msRest.ServiceCallback<Models.ApplicationGatewayPrivateEndpointConnection>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param connectionName The name of the application gateway private endpoint connection.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, applicationGatewayName: string, connectionName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ApplicationGatewayPrivateEndpointConnection>): void;
    /**
     * Lists all private endpoint connections on an application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.ApplicationGatewayPrivateEndpointConnectionsListResponse>
     */
    list(resourceGroupName: string, applicationGatewayName: string, options?: msRest.RequestOptionsBase): Promise<Models.ApplicationGatewayPrivateEndpointConnectionsListResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param callback The callback
     */
    list(resourceGroupName: string, applicationGatewayName: string, callback: msRest.ServiceCallback<Models.ApplicationGatewayPrivateEndpointConnectionListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param options The optional parameters
     * @param callback The callback
     */
    list(resourceGroupName: string, applicationGatewayName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ApplicationGatewayPrivateEndpointConnectionListResult>): void;
    /**
     * Deletes the specified private endpoint connection on application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param connectionName The name of the application gateway private endpoint connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, applicationGatewayName: string, connectionName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Updates the specified private endpoint connection on application gateway.
     * @param resourceGroupName The name of the resource group.
     * @param applicationGatewayName The name of the application gateway.
     * @param connectionName The name of the application gateway private endpoint connection.
     * @param parameters Parameters supplied to update application gateway private endpoint connection
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginUpdate(resourceGroupName: string, applicationGatewayName: string, connectionName: string, parameters: Models.ApplicationGatewayPrivateEndpointConnection, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Lists all private endpoint connections on an application gateway.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ApplicationGatewayPrivateEndpointConnectionsListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.ApplicationGatewayPrivateEndpointConnectionsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ApplicationGatewayPrivateEndpointConnectionListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ApplicationGatewayPrivateEndpointConnectionListResult>): void;
}
//# sourceMappingURL=applicationGatewayPrivateEndpointConnections.d.ts.map