/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/expressRouteCircuitConnectionsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a ExpressRouteCircuitConnections. */
var ExpressRouteCircuitConnections = /** @class */ (function () {
    /**
     * Create a ExpressRouteCircuitConnections.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function ExpressRouteCircuitConnections(client) {
        this.client = client;
    }
    /**
     * Deletes the specified Express Route Circuit Connection from the specified express route circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param connectionName The name of the express route circuit connection.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    ExpressRouteCircuitConnections.prototype.deleteMethod = function (resourceGroupName, circuitName, peeringName, connectionName, options) {
        return this.beginDeleteMethod(resourceGroupName, circuitName, peeringName, connectionName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteCircuitConnections.prototype.get = function (resourceGroupName, circuitName, peeringName, connectionName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            peeringName: peeringName,
            connectionName: connectionName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a Express Route Circuit Connection in the specified express route circuits.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param connectionName The name of the express route circuit connection.
     * @param expressRouteCircuitConnectionParameters Parameters supplied to the create or update
     * express route circuit connection operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRouteCircuitConnectionsCreateOrUpdateResponse>
     */
    ExpressRouteCircuitConnections.prototype.createOrUpdate = function (resourceGroupName, circuitName, peeringName, connectionName, expressRouteCircuitConnectionParameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, circuitName, peeringName, connectionName, expressRouteCircuitConnectionParameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    ExpressRouteCircuitConnections.prototype.list = function (resourceGroupName, circuitName, peeringName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            peeringName: peeringName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified Express Route Circuit Connection from the specified express route circuit.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param connectionName The name of the express route circuit connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCircuitConnections.prototype.beginDeleteMethod = function (resourceGroupName, circuitName, peeringName, connectionName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            peeringName: peeringName,
            connectionName: connectionName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a Express Route Circuit Connection in the specified express route circuits.
     * @param resourceGroupName The name of the resource group.
     * @param circuitName The name of the express route circuit.
     * @param peeringName The name of the peering.
     * @param connectionName The name of the express route circuit connection.
     * @param expressRouteCircuitConnectionParameters Parameters supplied to the create or update
     * express route circuit connection operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    ExpressRouteCircuitConnections.prototype.beginCreateOrUpdate = function (resourceGroupName, circuitName, peeringName, connectionName, expressRouteCircuitConnectionParameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            circuitName: circuitName,
            peeringName: peeringName,
            connectionName: connectionName,
            expressRouteCircuitConnectionParameters: expressRouteCircuitConnectionParameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    ExpressRouteCircuitConnections.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return ExpressRouteCircuitConnections;
}());
export { ExpressRouteCircuitConnections };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/peerings/{peeringName}/connections/{connectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.peeringName,
        Parameters.connectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/peerings/{peeringName}/connections",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.peeringName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitConnectionListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/peerings/{peeringName}/connections/{connectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.peeringName,
        Parameters.connectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/expressRouteCircuits/{circuitName}/peerings/{peeringName}/connections/{connectionName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.circuitName,
        Parameters.peeringName,
        Parameters.connectionName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "expressRouteCircuitConnectionParameters",
        mapper: __assign(__assign({}, Mappers.ExpressRouteCircuitConnection), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitConnection
        },
        201: {
            bodyMapper: Mappers.ExpressRouteCircuitConnection
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ExpressRouteCircuitConnectionListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=expressRouteCircuitConnections.js.map