import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a ExpressRoutePortsLocations. */
export declare class ExpressRoutePortsLocations {
    private readonly client;
    /**
     * Create a ExpressRoutePortsLocations.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Retrieves all ExpressRoutePort peering locations. Does not return available bandwidths for each
     * location. Available bandwidths can only be obtained when retrieving a specific peering location.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRoutePortsLocationsListResponse>
     */
    list(options?: msRest.RequestOptionsBase): Promise<Models.ExpressRoutePortsLocationsListResponse>;
    /**
     * @param callback The callback
     */
    list(callback: msRest.ServiceCallback<Models.ExpressRoutePortsLocationListResult>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    list(options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ExpressRoutePortsLocationListResult>): void;
    /**
     * Retrieves a single ExpressRoutePort peering location, including the list of available bandwidths
     * available at said peering location.
     * @param locationName Name of the requested ExpressRoutePort peering location.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRoutePortsLocationsGetResponse>
     */
    get(locationName: string, options?: msRest.RequestOptionsBase): Promise<Models.ExpressRoutePortsLocationsGetResponse>;
    /**
     * @param locationName Name of the requested ExpressRoutePort peering location.
     * @param callback The callback
     */
    get(locationName: string, callback: msRest.ServiceCallback<Models.ExpressRoutePortsLocation>): void;
    /**
     * @param locationName Name of the requested ExpressRoutePort peering location.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(locationName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ExpressRoutePortsLocation>): void;
    /**
     * Retrieves all ExpressRoutePort peering locations. Does not return available bandwidths for each
     * location. Available bandwidths can only be obtained when retrieving a specific peering location.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.ExpressRoutePortsLocationsListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.ExpressRoutePortsLocationsListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ExpressRoutePortsLocationListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ExpressRoutePortsLocationListResult>): void;
}
//# sourceMappingURL=expressRoutePortsLocations.d.ts.map