/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/firewallPolicyRuleCollectionGroupsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a FirewallPolicyRuleCollectionGroups. */
var FirewallPolicyRuleCollectionGroups = /** @class */ (function () {
    /**
     * Create a FirewallPolicyRuleCollectionGroups.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function FirewallPolicyRuleCollectionGroups(client) {
        this.client = client;
    }
    /**
     * Deletes the specified FirewallPolicyRuleCollectionGroup.
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param ruleCollectionGroupName The name of the FirewallPolicyRuleCollectionGroup.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    FirewallPolicyRuleCollectionGroups.prototype.deleteMethod = function (resourceGroupName, firewallPolicyName, ruleCollectionGroupName, options) {
        return this.beginDeleteMethod(resourceGroupName, firewallPolicyName, ruleCollectionGroupName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    FirewallPolicyRuleCollectionGroups.prototype.get = function (resourceGroupName, firewallPolicyName, ruleCollectionGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            firewallPolicyName: firewallPolicyName,
            ruleCollectionGroupName: ruleCollectionGroupName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates the specified FirewallPolicyRuleCollectionGroup.
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param ruleCollectionGroupName The name of the FirewallPolicyRuleCollectionGroup.
     * @param parameters Parameters supplied to the create or update FirewallPolicyRuleCollectionGroup
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.FirewallPolicyRuleCollectionGroupsCreateOrUpdateResponse>
     */
    FirewallPolicyRuleCollectionGroups.prototype.createOrUpdate = function (resourceGroupName, firewallPolicyName, ruleCollectionGroupName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, firewallPolicyName, ruleCollectionGroupName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    FirewallPolicyRuleCollectionGroups.prototype.list = function (resourceGroupName, firewallPolicyName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            firewallPolicyName: firewallPolicyName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Deletes the specified FirewallPolicyRuleCollectionGroup.
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param ruleCollectionGroupName The name of the FirewallPolicyRuleCollectionGroup.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    FirewallPolicyRuleCollectionGroups.prototype.beginDeleteMethod = function (resourceGroupName, firewallPolicyName, ruleCollectionGroupName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            firewallPolicyName: firewallPolicyName,
            ruleCollectionGroupName: ruleCollectionGroupName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates the specified FirewallPolicyRuleCollectionGroup.
     * @param resourceGroupName The name of the resource group.
     * @param firewallPolicyName The name of the Firewall Policy.
     * @param ruleCollectionGroupName The name of the FirewallPolicyRuleCollectionGroup.
     * @param parameters Parameters supplied to the create or update FirewallPolicyRuleCollectionGroup
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    FirewallPolicyRuleCollectionGroups.prototype.beginCreateOrUpdate = function (resourceGroupName, firewallPolicyName, ruleCollectionGroupName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            firewallPolicyName: firewallPolicyName,
            ruleCollectionGroupName: ruleCollectionGroupName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    FirewallPolicyRuleCollectionGroups.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return FirewallPolicyRuleCollectionGroups;
}());
export { FirewallPolicyRuleCollectionGroups };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/firewallPolicies/{firewallPolicyName}/ruleCollectionGroups/{ruleCollectionGroupName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.firewallPolicyName,
        Parameters.ruleCollectionGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.FirewallPolicyRuleCollectionGroup
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/firewallPolicies/{firewallPolicyName}/ruleCollectionGroups",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.firewallPolicyName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.FirewallPolicyRuleCollectionGroupListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/firewallPolicies/{firewallPolicyName}/ruleCollectionGroups/{ruleCollectionGroupName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.firewallPolicyName,
        Parameters.ruleCollectionGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/firewallPolicies/{firewallPolicyName}/ruleCollectionGroups/{ruleCollectionGroupName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.firewallPolicyName,
        Parameters.ruleCollectionGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.FirewallPolicyRuleCollectionGroup), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.FirewallPolicyRuleCollectionGroup
        },
        201: {
            bodyMapper: Mappers.FirewallPolicyRuleCollectionGroup
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.FirewallPolicyRuleCollectionGroupListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=firewallPolicyRuleCollectionGroups.js.map