/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/flowLogsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a FlowLogs. */
var FlowLogs = /** @class */ (function () {
    /**
     * Create a FlowLogs.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function FlowLogs(client) {
        this.client = client;
    }
    /**
     * Create or update a flow log for the specified network security group.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log.
     * @param parameters Parameters that define the create or update flow log resource.
     * @param [options] The optional parameters
     * @returns Promise<Models.FlowLogsCreateOrUpdateResponse>
     */
    FlowLogs.prototype.createOrUpdate = function (resourceGroupName, networkWatcherName, flowLogName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, networkWatcherName, flowLogName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    FlowLogs.prototype.updateTags = function (resourceGroupName, networkWatcherName, flowLogName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            flowLogName: flowLogName,
            parameters: parameters,
            options: options
        }, updateTagsOperationSpec, callback);
    };
    FlowLogs.prototype.get = function (resourceGroupName, networkWatcherName, flowLogName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            flowLogName: flowLogName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Deletes the specified flow log resource.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log resource.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    FlowLogs.prototype.deleteMethod = function (resourceGroupName, networkWatcherName, flowLogName, options) {
        return this.beginDeleteMethod(resourceGroupName, networkWatcherName, flowLogName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    FlowLogs.prototype.list = function (resourceGroupName, networkWatcherName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Create or update a flow log for the specified network security group.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log.
     * @param parameters Parameters that define the create or update flow log resource.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    FlowLogs.prototype.beginCreateOrUpdate = function (resourceGroupName, networkWatcherName, flowLogName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            flowLogName: flowLogName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes the specified flow log resource.
     * @param resourceGroupName The name of the resource group.
     * @param networkWatcherName The name of the network watcher.
     * @param flowLogName The name of the flow log resource.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    FlowLogs.prototype.beginDeleteMethod = function (resourceGroupName, networkWatcherName, flowLogName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            networkWatcherName: networkWatcherName,
            flowLogName: flowLogName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    FlowLogs.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return FlowLogs;
}());
export { FlowLogs };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var updateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/flowLogs/{flowLogName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.flowLogName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.FlowLog
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/flowLogs/{flowLogName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.flowLogName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.FlowLog
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/flowLogs",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.FlowLogListResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/flowLogs/{flowLogName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.flowLogName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.FlowLog), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.FlowLog
        },
        201: {
            bodyMapper: Mappers.FlowLog
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/networkWatchers/{networkWatcherName}/flowLogs/{flowLogName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.networkWatcherName,
        Parameters.flowLogName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.FlowLogListResult
        },
        default: {
            bodyMapper: Mappers.ErrorResponse
        }
    },
    serializer: serializer
};
//# sourceMappingURL=flowLogs.js.map