/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/loadBalancerBackendAddressPoolsMappers";
import * as Parameters from "../models/parameters";
/** Class representing a LoadBalancerBackendAddressPools. */
var LoadBalancerBackendAddressPools = /** @class */ (function () {
    /**
     * Create a LoadBalancerBackendAddressPools.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function LoadBalancerBackendAddressPools(client) {
        this.client = client;
    }
    LoadBalancerBackendAddressPools.prototype.list = function (resourceGroupName, loadBalancerName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            loadBalancerName: loadBalancerName,
            options: options
        }, listOperationSpec, callback);
    };
    LoadBalancerBackendAddressPools.prototype.get = function (resourceGroupName, loadBalancerName, backendAddressPoolName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            loadBalancerName: loadBalancerName,
            backendAddressPoolName: backendAddressPoolName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a load balancer backend address pool.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param backendAddressPoolName The name of the backend address pool.
     * @param parameters Parameters supplied to the create or update load balancer backend address pool
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.LoadBalancerBackendAddressPoolsCreateOrUpdateResponse>
     */
    LoadBalancerBackendAddressPools.prototype.createOrUpdate = function (resourceGroupName, loadBalancerName, backendAddressPoolName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, loadBalancerName, backendAddressPoolName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes the specified load balancer backend address pool.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param backendAddressPoolName The name of the backend address pool.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    LoadBalancerBackendAddressPools.prototype.deleteMethod = function (resourceGroupName, loadBalancerName, backendAddressPoolName, options) {
        return this.beginDeleteMethod(resourceGroupName, loadBalancerName, backendAddressPoolName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Creates or updates a load balancer backend address pool.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param backendAddressPoolName The name of the backend address pool.
     * @param parameters Parameters supplied to the create or update load balancer backend address pool
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    LoadBalancerBackendAddressPools.prototype.beginCreateOrUpdate = function (resourceGroupName, loadBalancerName, backendAddressPoolName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            loadBalancerName: loadBalancerName,
            backendAddressPoolName: backendAddressPoolName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes the specified load balancer backend address pool.
     * @param resourceGroupName The name of the resource group.
     * @param loadBalancerName The name of the load balancer.
     * @param backendAddressPoolName The name of the backend address pool.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    LoadBalancerBackendAddressPools.prototype.beginDeleteMethod = function (resourceGroupName, loadBalancerName, backendAddressPoolName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            loadBalancerName: loadBalancerName,
            backendAddressPoolName: backendAddressPoolName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    LoadBalancerBackendAddressPools.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return LoadBalancerBackendAddressPools;
}());
export { LoadBalancerBackendAddressPools };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/backendAddressPools",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.loadBalancerName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.LoadBalancerBackendAddressPoolListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/backendAddressPools/{backendAddressPoolName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.loadBalancerName,
        Parameters.backendAddressPoolName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.BackendAddressPool
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/backendAddressPools/{backendAddressPoolName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.loadBalancerName,
        Parameters.backendAddressPoolName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.BackendAddressPool), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.BackendAddressPool
        },
        201: {
            bodyMapper: Mappers.BackendAddressPool
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/loadBalancers/{loadBalancerName}/backendAddressPools/{backendAddressPoolName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.loadBalancerName,
        Parameters.backendAddressPoolName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.LoadBalancerBackendAddressPoolListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=loadBalancerBackendAddressPools.js.map