/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/publicIPAddressesMappers";
import * as Parameters from "../models/parameters";
/** Class representing a PublicIPAddresses. */
var PublicIPAddresses = /** @class */ (function () {
    /**
     * Create a PublicIPAddresses.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function PublicIPAddresses(client) {
        this.client = client;
    }
    PublicIPAddresses.prototype.listCloudServicePublicIPAddresses = function (resourceGroupName, cloudServiceName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            cloudServiceName: cloudServiceName,
            options: options
        }, listCloudServicePublicIPAddressesOperationSpec, callback);
    };
    PublicIPAddresses.prototype.listCloudServiceRoleInstancePublicIPAddresses = function (resourceGroupName, cloudServiceName, roleInstanceName, networkInterfaceName, ipConfigurationName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            cloudServiceName: cloudServiceName,
            roleInstanceName: roleInstanceName,
            networkInterfaceName: networkInterfaceName,
            ipConfigurationName: ipConfigurationName,
            options: options
        }, listCloudServiceRoleInstancePublicIPAddressesOperationSpec, callback);
    };
    PublicIPAddresses.prototype.getCloudServicePublicIPAddress = function (resourceGroupName, cloudServiceName, roleInstanceName, networkInterfaceName, ipConfigurationName, publicIpAddressName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            cloudServiceName: cloudServiceName,
            roleInstanceName: roleInstanceName,
            networkInterfaceName: networkInterfaceName,
            ipConfigurationName: ipConfigurationName,
            publicIpAddressName: publicIpAddressName,
            options: options
        }, getCloudServicePublicIPAddressOperationSpec, callback);
    };
    /**
     * Deletes the specified public IP address.
     * @param resourceGroupName The name of the resource group.
     * @param publicIpAddressName The name of the public IP address.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    PublicIPAddresses.prototype.deleteMethod = function (resourceGroupName, publicIpAddressName, options) {
        return this.beginDeleteMethod(resourceGroupName, publicIpAddressName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    PublicIPAddresses.prototype.get = function (resourceGroupName, publicIpAddressName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            publicIpAddressName: publicIpAddressName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates or updates a static or dynamic public IP address.
     * @param resourceGroupName The name of the resource group.
     * @param publicIpAddressName The name of the public IP address.
     * @param parameters Parameters supplied to the create or update public IP address operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PublicIPAddressesCreateOrUpdateResponse>
     */
    PublicIPAddresses.prototype.createOrUpdate = function (resourceGroupName, publicIpAddressName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, publicIpAddressName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    PublicIPAddresses.prototype.updateTags = function (resourceGroupName, publicIpAddressName, parameters, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            publicIpAddressName: publicIpAddressName,
            parameters: parameters,
            options: options
        }, updateTagsOperationSpec, callback);
    };
    PublicIPAddresses.prototype.listAll = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listAllOperationSpec, callback);
    };
    PublicIPAddresses.prototype.list = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listOperationSpec, callback);
    };
    PublicIPAddresses.prototype.listVirtualMachineScaleSetPublicIPAddresses = function (resourceGroupName, virtualMachineScaleSetName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualMachineScaleSetName: virtualMachineScaleSetName,
            options: options
        }, listVirtualMachineScaleSetPublicIPAddressesOperationSpec, callback);
    };
    PublicIPAddresses.prototype.listVirtualMachineScaleSetVMPublicIPAddresses = function (resourceGroupName, virtualMachineScaleSetName, virtualmachineIndex, networkInterfaceName, ipConfigurationName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualMachineScaleSetName: virtualMachineScaleSetName,
            virtualmachineIndex: virtualmachineIndex,
            networkInterfaceName: networkInterfaceName,
            ipConfigurationName: ipConfigurationName,
            options: options
        }, listVirtualMachineScaleSetVMPublicIPAddressesOperationSpec, callback);
    };
    PublicIPAddresses.prototype.getVirtualMachineScaleSetPublicIPAddress = function (resourceGroupName, virtualMachineScaleSetName, virtualmachineIndex, networkInterfaceName, ipConfigurationName, publicIpAddressName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualMachineScaleSetName: virtualMachineScaleSetName,
            virtualmachineIndex: virtualmachineIndex,
            networkInterfaceName: networkInterfaceName,
            ipConfigurationName: ipConfigurationName,
            publicIpAddressName: publicIpAddressName,
            options: options
        }, getVirtualMachineScaleSetPublicIPAddressOperationSpec, callback);
    };
    /**
     * Deletes the specified public IP address.
     * @param resourceGroupName The name of the resource group.
     * @param publicIpAddressName The name of the public IP address.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    PublicIPAddresses.prototype.beginDeleteMethod = function (resourceGroupName, publicIpAddressName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            publicIpAddressName: publicIpAddressName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    /**
     * Creates or updates a static or dynamic public IP address.
     * @param resourceGroupName The name of the resource group.
     * @param publicIpAddressName The name of the public IP address.
     * @param parameters Parameters supplied to the create or update public IP address operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    PublicIPAddresses.prototype.beginCreateOrUpdate = function (resourceGroupName, publicIpAddressName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            publicIpAddressName: publicIpAddressName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    PublicIPAddresses.prototype.listCloudServicePublicIPAddressesNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listCloudServicePublicIPAddressesNextOperationSpec, callback);
    };
    PublicIPAddresses.prototype.listCloudServiceRoleInstancePublicIPAddressesNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listCloudServiceRoleInstancePublicIPAddressesNextOperationSpec, callback);
    };
    PublicIPAddresses.prototype.listAllNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listAllNextOperationSpec, callback);
    };
    PublicIPAddresses.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    PublicIPAddresses.prototype.listVirtualMachineScaleSetPublicIPAddressesNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listVirtualMachineScaleSetPublicIPAddressesNextOperationSpec, callback);
    };
    PublicIPAddresses.prototype.listVirtualMachineScaleSetVMPublicIPAddressesNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listVirtualMachineScaleSetVMPublicIPAddressesNextOperationSpec, callback);
    };
    return PublicIPAddresses;
}());
export { PublicIPAddresses };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var listCloudServicePublicIPAddressesOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/cloudServices/{cloudServiceName}/publicipaddresses",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.cloudServiceName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddressListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listCloudServiceRoleInstancePublicIPAddressesOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/cloudServices/{cloudServiceName}/roleInstances/{roleInstanceName}/networkInterfaces/{networkInterfaceName}/ipconfigurations/{ipConfigurationName}/publicipaddresses",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.cloudServiceName,
        Parameters.roleInstanceName,
        Parameters.networkInterfaceName,
        Parameters.ipConfigurationName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddressListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getCloudServicePublicIPAddressOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/cloudServices/{cloudServiceName}/roleInstances/{roleInstanceName}/networkInterfaces/{networkInterfaceName}/ipconfigurations/{ipConfigurationName}/publicipaddresses/{publicIpAddressName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.cloudServiceName,
        Parameters.roleInstanceName,
        Parameters.networkInterfaceName,
        Parameters.ipConfigurationName,
        Parameters.publicIpAddressName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0,
        Parameters.expand
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddress
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/publicIPAddresses/{publicIpAddressName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.publicIpAddressName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0,
        Parameters.expand
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddress
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var updateTagsOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/publicIPAddresses/{publicIpAddressName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.publicIpAddressName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.TagsObject), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddress
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listAllOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/publicIPAddresses",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddressListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/publicIPAddresses",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddressListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listVirtualMachineScaleSetPublicIPAddressesOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{virtualMachineScaleSetName}/publicipaddresses",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualMachineScaleSetName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddressListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listVirtualMachineScaleSetVMPublicIPAddressesOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{virtualMachineScaleSetName}/virtualMachines/{virtualmachineIndex}/networkInterfaces/{networkInterfaceName}/ipconfigurations/{ipConfigurationName}/publicipaddresses",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualMachineScaleSetName,
        Parameters.virtualmachineIndex,
        Parameters.networkInterfaceName,
        Parameters.ipConfigurationName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddressListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var getVirtualMachineScaleSetPublicIPAddressOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{virtualMachineScaleSetName}/virtualMachines/{virtualmachineIndex}/networkInterfaces/{networkInterfaceName}/ipconfigurations/{ipConfigurationName}/publicipaddresses/{publicIpAddressName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.virtualMachineScaleSetName,
        Parameters.virtualmachineIndex,
        Parameters.networkInterfaceName,
        Parameters.ipConfigurationName,
        Parameters.publicIpAddressName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion1,
        Parameters.expand
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddress
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/publicIPAddresses/{publicIpAddressName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.publicIpAddressName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/publicIPAddresses/{publicIpAddressName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.publicIpAddressName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.PublicIPAddress), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddress
        },
        201: {
            bodyMapper: Mappers.PublicIPAddress
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listCloudServicePublicIPAddressesNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddressListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listCloudServiceRoleInstancePublicIPAddressesNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddressListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listAllNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddressListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddressListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listVirtualMachineScaleSetPublicIPAddressesNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddressListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listVirtualMachineScaleSetVMPublicIPAddressesNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion1
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PublicIPAddressListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=publicIPAddresses.js.map