import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a SecurityPartnerProviders. */
export declare class SecurityPartnerProviders {
    private readonly client;
    /**
     * Create a SecurityPartnerProviders.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Deletes the specified Security Partner Provider.
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, securityPartnerProviderName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Gets the specified Security Partner Provider.
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param [options] The optional parameters
     * @returns Promise<Models.SecurityPartnerProvidersGetResponse>
     */
    get(resourceGroupName: string, securityPartnerProviderName: string, options?: msRest.RequestOptionsBase): Promise<Models.SecurityPartnerProvidersGetResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param callback The callback
     */
    get(resourceGroupName: string, securityPartnerProviderName: string, callback: msRest.ServiceCallback<Models.SecurityPartnerProvider>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, securityPartnerProviderName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.SecurityPartnerProvider>): void;
    /**
     * Creates or updates the specified Security Partner Provider.
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param parameters Parameters supplied to the create or update Security Partner Provider
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.SecurityPartnerProvidersCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, securityPartnerProviderName: string, parameters: Models.SecurityPartnerProvider, options?: msRest.RequestOptionsBase): Promise<Models.SecurityPartnerProvidersCreateOrUpdateResponse>;
    /**
     * Updates tags of a Security Partner Provider resource.
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param parameters Parameters supplied to update Security Partner Provider tags.
     * @param [options] The optional parameters
     * @returns Promise<Models.SecurityPartnerProvidersUpdateTagsResponse>
     */
    updateTags(resourceGroupName: string, securityPartnerProviderName: string, parameters: Models.TagsObject, options?: msRest.RequestOptionsBase): Promise<Models.SecurityPartnerProvidersUpdateTagsResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param parameters Parameters supplied to update Security Partner Provider tags.
     * @param callback The callback
     */
    updateTags(resourceGroupName: string, securityPartnerProviderName: string, parameters: Models.TagsObject, callback: msRest.ServiceCallback<Models.SecurityPartnerProvider>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param parameters Parameters supplied to update Security Partner Provider tags.
     * @param options The optional parameters
     * @param callback The callback
     */
    updateTags(resourceGroupName: string, securityPartnerProviderName: string, parameters: Models.TagsObject, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.SecurityPartnerProvider>): void;
    /**
     * Lists all Security Partner Providers in a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param [options] The optional parameters
     * @returns Promise<Models.SecurityPartnerProvidersListByResourceGroupResponse>
     */
    listByResourceGroup(resourceGroupName: string, options?: msRest.RequestOptionsBase): Promise<Models.SecurityPartnerProvidersListByResourceGroupResponse>;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param callback The callback
     */
    listByResourceGroup(resourceGroupName: string, callback: msRest.ServiceCallback<Models.SecurityPartnerProviderListResult>): void;
    /**
     * @param resourceGroupName The name of the resource group.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByResourceGroup(resourceGroupName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.SecurityPartnerProviderListResult>): void;
    /**
     * Gets all the Security Partner Providers in a subscription.
     * @param [options] The optional parameters
     * @returns Promise<Models.SecurityPartnerProvidersListResponse>
     */
    list(options?: msRest.RequestOptionsBase): Promise<Models.SecurityPartnerProvidersListResponse>;
    /**
     * @param callback The callback
     */
    list(callback: msRest.ServiceCallback<Models.SecurityPartnerProviderListResult>): void;
    /**
     * @param options The optional parameters
     * @param callback The callback
     */
    list(options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.SecurityPartnerProviderListResult>): void;
    /**
     * Deletes the specified Security Partner Provider.
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, securityPartnerProviderName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Creates or updates the specified Security Partner Provider.
     * @param resourceGroupName The name of the resource group.
     * @param securityPartnerProviderName The name of the Security Partner Provider.
     * @param parameters Parameters supplied to the create or update Security Partner Provider
     * operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, securityPartnerProviderName: string, parameters: Models.SecurityPartnerProvider, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Lists all Security Partner Providers in a resource group.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.SecurityPartnerProvidersListByResourceGroupNextResponse>
     */
    listByResourceGroupNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.SecurityPartnerProvidersListByResourceGroupNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByResourceGroupNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.SecurityPartnerProviderListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByResourceGroupNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.SecurityPartnerProviderListResult>): void;
    /**
     * Gets all the Security Partner Providers in a subscription.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.SecurityPartnerProvidersListNextResponse>
     */
    listNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.SecurityPartnerProvidersListNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.SecurityPartnerProviderListResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.SecurityPartnerProviderListResult>): void;
}
//# sourceMappingURL=securityPartnerProviders.d.ts.map