/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/virtualHubIpConfigurationMappers";
import * as Parameters from "../models/parameters";
/** Class representing a VirtualHubIpConfiguration. */
var VirtualHubIpConfiguration = /** @class */ (function () {
    /**
     * Create a VirtualHubIpConfiguration.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    function VirtualHubIpConfiguration(client) {
        this.client = client;
    }
    VirtualHubIpConfiguration.prototype.get = function (resourceGroupName, virtualHubName, ipConfigName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            ipConfigName: ipConfigName,
            options: options
        }, getOperationSpec, callback);
    };
    /**
     * Creates a VirtualHubIpConfiguration resource if it doesn't exist else updates the existing
     * VirtualHubIpConfiguration.
     * @param resourceGroupName The resource group name of the VirtualHub.
     * @param virtualHubName The name of the VirtualHub.
     * @param ipConfigName The name of the ipconfig.
     * @param parameters Hub Ip Configuration parameters.
     * @param [options] The optional parameters
     * @returns Promise<Models.VirtualHubIpConfigurationCreateOrUpdateResponse>
     */
    VirtualHubIpConfiguration.prototype.createOrUpdate = function (resourceGroupName, virtualHubName, ipConfigName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, virtualHubName, ipConfigName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes a VirtualHubIpConfiguration.
     * @param resourceGroupName The resource group name of the VirtualHubBgpConnection.
     * @param virtualHubName The name of the VirtualHub.
     * @param ipConfigName The name of the ipconfig.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    VirtualHubIpConfiguration.prototype.deleteMethod = function (resourceGroupName, virtualHubName, ipConfigName, options) {
        return this.beginDeleteMethod(resourceGroupName, virtualHubName, ipConfigName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    VirtualHubIpConfiguration.prototype.list = function (resourceGroupName, virtualHubName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            options: options
        }, listOperationSpec, callback);
    };
    /**
     * Creates a VirtualHubIpConfiguration resource if it doesn't exist else updates the existing
     * VirtualHubIpConfiguration.
     * @param resourceGroupName The resource group name of the VirtualHub.
     * @param virtualHubName The name of the VirtualHub.
     * @param ipConfigName The name of the ipconfig.
     * @param parameters Hub Ip Configuration parameters.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualHubIpConfiguration.prototype.beginCreateOrUpdate = function (resourceGroupName, virtualHubName, ipConfigName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            ipConfigName: ipConfigName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Deletes a VirtualHubIpConfiguration.
     * @param resourceGroupName The resource group name of the VirtualHubBgpConnection.
     * @param virtualHubName The name of the VirtualHub.
     * @param ipConfigName The name of the ipconfig.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    VirtualHubIpConfiguration.prototype.beginDeleteMethod = function (resourceGroupName, virtualHubName, ipConfigName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            virtualHubName: virtualHubName,
            ipConfigName: ipConfigName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    VirtualHubIpConfiguration.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    return VirtualHubIpConfiguration;
}());
export { VirtualHubIpConfiguration };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/ipConfigurations/{ipConfigName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName,
        Parameters.ipConfigName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.HubIpConfiguration
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/ipConfigurations",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListVirtualHubIpConfigurationResults
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/ipConfigurations/{ipConfigName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName,
        Parameters.ipConfigName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.HubIpConfiguration), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.HubIpConfiguration
        },
        201: {
            bodyMapper: Mappers.HubIpConfiguration
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/virtualHubs/{virtualHubName}/ipConfigurations/{ipConfigName}",
    urlParameters: [
        Parameters.subscriptionId,
        Parameters.resourceGroupName,
        Parameters.virtualHubName,
        Parameters.ipConfigName
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    queryParameters: [
        Parameters.apiVersion0
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.ListVirtualHubIpConfigurationResults
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=virtualHubIpConfiguration.js.map