import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a VpnConnections. */
export declare class VpnConnections {
    private readonly client;
    /**
     * Create a VpnConnections.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Retrieves the details of a vpn connection.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnConnectionsGetResponse>
     */
    get(resourceGroupName: string, gatewayName: string, connectionName: string, options?: msRest.RequestOptionsBase): Promise<Models.VpnConnectionsGetResponse>;
    /**
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param callback The callback
     */
    get(resourceGroupName: string, gatewayName: string, connectionName: string, callback: msRest.ServiceCallback<Models.VpnConnection>): void;
    /**
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param options The optional parameters
     * @param callback The callback
     */
    get(resourceGroupName: string, gatewayName: string, connectionName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.VpnConnection>): void;
    /**
     * Creates a vpn connection to a scalable vpn gateway if it doesn't exist else updates the existing
     * connection.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the connection.
     * @param vpnConnectionParameters Parameters supplied to create or Update a VPN Connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnConnectionsCreateOrUpdateResponse>
     */
    createOrUpdate(resourceGroupName: string, gatewayName: string, connectionName: string, vpnConnectionParameters: Models.VpnConnection, options?: msRest.RequestOptionsBase): Promise<Models.VpnConnectionsCreateOrUpdateResponse>;
    /**
     * Deletes a vpn connection.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the connection.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    deleteMethod(resourceGroupName: string, gatewayName: string, connectionName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Starts packet capture on Vpn connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param vpnConnectionName The name of the vpn connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnConnectionsStartPacketCaptureResponse>
     */
    startPacketCapture(resourceGroupName: string, gatewayName: string, vpnConnectionName: string, options?: Models.VpnConnectionsStartPacketCaptureOptionalParams): Promise<Models.VpnConnectionsStartPacketCaptureResponse>;
    /**
     * Stops packet capture on Vpn connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param vpnConnectionName The name of the vpn connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnConnectionsStopPacketCaptureResponse>
     */
    stopPacketCapture(resourceGroupName: string, gatewayName: string, vpnConnectionName: string, options?: Models.VpnConnectionsStopPacketCaptureOptionalParams): Promise<Models.VpnConnectionsStopPacketCaptureResponse>;
    /**
     * Retrieves all vpn connections for a particular virtual wan vpn gateway.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnConnectionsListByVpnGatewayResponse>
     */
    listByVpnGateway(resourceGroupName: string, gatewayName: string, options?: msRest.RequestOptionsBase): Promise<Models.VpnConnectionsListByVpnGatewayResponse>;
    /**
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param callback The callback
     */
    listByVpnGateway(resourceGroupName: string, gatewayName: string, callback: msRest.ServiceCallback<Models.ListVpnConnectionsResult>): void;
    /**
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByVpnGateway(resourceGroupName: string, gatewayName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVpnConnectionsResult>): void;
    /**
     * Creates a vpn connection to a scalable vpn gateway if it doesn't exist else updates the existing
     * connection.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the connection.
     * @param vpnConnectionParameters Parameters supplied to create or Update a VPN Connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginCreateOrUpdate(resourceGroupName: string, gatewayName: string, connectionName: string, vpnConnectionParameters: Models.VpnConnection, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Deletes a vpn connection.
     * @param resourceGroupName The resource group name of the VpnGateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginDeleteMethod(resourceGroupName: string, gatewayName: string, connectionName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Starts packet capture on Vpn connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param vpnConnectionName The name of the vpn connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginStartPacketCapture(resourceGroupName: string, gatewayName: string, vpnConnectionName: string, options?: Models.VpnConnectionsBeginStartPacketCaptureOptionalParams): Promise<msRestAzure.LROPoller>;
    /**
     * Stops packet capture on Vpn connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param vpnConnectionName The name of the vpn connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginStopPacketCapture(resourceGroupName: string, gatewayName: string, vpnConnectionName: string, options?: Models.VpnConnectionsBeginStopPacketCaptureOptionalParams): Promise<msRestAzure.LROPoller>;
    /**
     * Retrieves all vpn connections for a particular virtual wan vpn gateway.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnConnectionsListByVpnGatewayNextResponse>
     */
    listByVpnGatewayNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.VpnConnectionsListByVpnGatewayNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByVpnGatewayNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ListVpnConnectionsResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByVpnGatewayNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVpnConnectionsResult>): void;
}
//# sourceMappingURL=vpnConnections.d.ts.map