import * as msRest from "@azure/ms-rest-js";
import * as msRestAzure from "@azure/ms-rest-azure-js";
import * as Models from "../models";
import { NetworkManagementClientContext } from "../networkManagementClientContext";
/** Class representing a VpnLinkConnections. */
export declare class VpnLinkConnections {
    private readonly client;
    /**
     * Create a VpnLinkConnections.
     * @param {NetworkManagementClientContext} client Reference to the service client.
     */
    constructor(client: NetworkManagementClientContext);
    /**
     * Resets the VpnLink connection specified.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param linkConnectionName The name of the vpn link connection.
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    resetConnection(resourceGroupName: string, gatewayName: string, connectionName: string, linkConnectionName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
    /**
     * Lists IKE Security Associations for Vpn Site Link Connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param linkConnectionName The name of the vpn link connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnLinkConnectionsGetIkeSasResponse>
     */
    getIkeSas(resourceGroupName: string, gatewayName: string, connectionName: string, linkConnectionName: string, options?: msRest.RequestOptionsBase): Promise<Models.VpnLinkConnectionsGetIkeSasResponse>;
    /**
     * Retrieves all vpn site link connections for a particular virtual wan vpn gateway vpn connection.
     * @param resourceGroupName The resource group name of the vpn gateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnLinkConnectionsListByVpnConnectionResponse>
     */
    listByVpnConnection(resourceGroupName: string, gatewayName: string, connectionName: string, options?: msRest.RequestOptionsBase): Promise<Models.VpnLinkConnectionsListByVpnConnectionResponse>;
    /**
     * @param resourceGroupName The resource group name of the vpn gateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param callback The callback
     */
    listByVpnConnection(resourceGroupName: string, gatewayName: string, connectionName: string, callback: msRest.ServiceCallback<Models.ListVpnSiteLinkConnectionsResult>): void;
    /**
     * @param resourceGroupName The resource group name of the vpn gateway.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByVpnConnection(resourceGroupName: string, gatewayName: string, connectionName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVpnSiteLinkConnectionsResult>): void;
    /**
     * Resets the VpnLink connection specified.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param linkConnectionName The name of the vpn link connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginResetConnection(resourceGroupName: string, gatewayName: string, connectionName: string, linkConnectionName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Lists IKE Security Associations for Vpn Site Link Connection in the specified resource group.
     * @param resourceGroupName The name of the resource group.
     * @param gatewayName The name of the gateway.
     * @param connectionName The name of the vpn connection.
     * @param linkConnectionName The name of the vpn link connection.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    beginGetIkeSas(resourceGroupName: string, gatewayName: string, connectionName: string, linkConnectionName: string, options?: msRest.RequestOptionsBase): Promise<msRestAzure.LROPoller>;
    /**
     * Retrieves all vpn site link connections for a particular virtual wan vpn gateway vpn connection.
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.VpnLinkConnectionsListByVpnConnectionNextResponse>
     */
    listByVpnConnectionNext(nextPageLink: string, options?: msRest.RequestOptionsBase): Promise<Models.VpnLinkConnectionsListByVpnConnectionNextResponse>;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param callback The callback
     */
    listByVpnConnectionNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ListVpnSiteLinkConnectionsResult>): void;
    /**
     * @param nextPageLink The NextLink from the previous successful call to List operation.
     * @param options The optional parameters
     * @param callback The callback
     */
    listByVpnConnectionNext(nextPageLink: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.ListVpnSiteLinkConnectionsResult>): void;
}
//# sourceMappingURL=vpnLinkConnections.d.ts.map