/*
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for
 * license information.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */
import { __assign } from "tslib";
import * as msRest from "@azure/ms-rest-js";
import * as Mappers from "../models/privateZonesMappers";
import * as Parameters from "../models/parameters";
/** Class representing a PrivateZones. */
var PrivateZones = /** @class */ (function () {
    /**
     * Create a PrivateZones.
     * @param {PrivateDnsManagementClientContext} client Reference to the service client.
     */
    function PrivateZones(client) {
        this.client = client;
    }
    /**
     * Creates or updates a Private DNS zone. Does not modify Links to virtual networks or DNS records
     * within the zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param parameters Parameters supplied to the CreateOrUpdate operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateZonesCreateOrUpdateResponse>
     */
    PrivateZones.prototype.createOrUpdate = function (resourceGroupName, privateZoneName, parameters, options) {
        return this.beginCreateOrUpdate(resourceGroupName, privateZoneName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Updates a Private DNS zone. Does not modify virtual network links or DNS records within the
     * zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param parameters Parameters supplied to the Update operation.
     * @param [options] The optional parameters
     * @returns Promise<Models.PrivateZonesUpdateResponse>
     */
    PrivateZones.prototype.update = function (resourceGroupName, privateZoneName, parameters, options) {
        return this.beginUpdate(resourceGroupName, privateZoneName, parameters, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    /**
     * Deletes a Private DNS zone. WARNING: All DNS records in the zone will also be deleted. This
     * operation cannot be undone. Private DNS zone cannot be deleted unless all virtual network links
     * to it are removed.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param [options] The optional parameters
     * @returns Promise<msRest.RestResponse>
     */
    PrivateZones.prototype.deleteMethod = function (resourceGroupName, privateZoneName, options) {
        return this.beginDeleteMethod(resourceGroupName, privateZoneName, options)
            .then(function (lroPoller) { return lroPoller.pollUntilFinished(); });
    };
    PrivateZones.prototype.get = function (resourceGroupName, privateZoneName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            options: options
        }, getOperationSpec, callback);
    };
    PrivateZones.prototype.list = function (options, callback) {
        return this.client.sendOperationRequest({
            options: options
        }, listOperationSpec, callback);
    };
    PrivateZones.prototype.listByResourceGroup = function (resourceGroupName, options, callback) {
        return this.client.sendOperationRequest({
            resourceGroupName: resourceGroupName,
            options: options
        }, listByResourceGroupOperationSpec, callback);
    };
    /**
     * Creates or updates a Private DNS zone. Does not modify Links to virtual networks or DNS records
     * within the zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param parameters Parameters supplied to the CreateOrUpdate operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    PrivateZones.prototype.beginCreateOrUpdate = function (resourceGroupName, privateZoneName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            parameters: parameters,
            options: options
        }, beginCreateOrUpdateOperationSpec, options);
    };
    /**
     * Updates a Private DNS zone. Does not modify virtual network links or DNS records within the
     * zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param parameters Parameters supplied to the Update operation.
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    PrivateZones.prototype.beginUpdate = function (resourceGroupName, privateZoneName, parameters, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            parameters: parameters,
            options: options
        }, beginUpdateOperationSpec, options);
    };
    /**
     * Deletes a Private DNS zone. WARNING: All DNS records in the zone will also be deleted. This
     * operation cannot be undone. Private DNS zone cannot be deleted unless all virtual network links
     * to it are removed.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param [options] The optional parameters
     * @returns Promise<msRestAzure.LROPoller>
     */
    PrivateZones.prototype.beginDeleteMethod = function (resourceGroupName, privateZoneName, options) {
        return this.client.sendLRORequest({
            resourceGroupName: resourceGroupName,
            privateZoneName: privateZoneName,
            options: options
        }, beginDeleteMethodOperationSpec, options);
    };
    PrivateZones.prototype.listNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listNextOperationSpec, callback);
    };
    PrivateZones.prototype.listByResourceGroupNext = function (nextPageLink, options, callback) {
        return this.client.sendOperationRequest({
            nextPageLink: nextPageLink,
            options: options
        }, listByResourceGroupNextOperationSpec, callback);
    };
    return PrivateZones;
}());
export { PrivateZones };
// Operation Specifications
var serializer = new msRest.Serializer(Mappers);
var getOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PrivateZone
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/providers/Microsoft.Network/privateDnsZones",
    urlParameters: [
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.top,
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PrivateZoneListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByResourceGroupOperationSpec = {
    httpMethod: "GET",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.top,
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PrivateZoneListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginCreateOrUpdateOperationSpec = {
    httpMethod: "PUT",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.ifMatch,
        Parameters.ifNoneMatch,
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.PrivateZone), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.PrivateZone
        },
        201: {
            bodyMapper: Mappers.PrivateZone
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginUpdateOperationSpec = {
    httpMethod: "PATCH",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.ifMatch,
        Parameters.acceptLanguage
    ],
    requestBody: {
        parameterPath: "parameters",
        mapper: __assign(__assign({}, Mappers.PrivateZone), { required: true })
    },
    responses: {
        200: {
            bodyMapper: Mappers.PrivateZone
        },
        202: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var beginDeleteMethodOperationSpec = {
    httpMethod: "DELETE",
    path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/privateDnsZones/{privateZoneName}",
    urlParameters: [
        Parameters.resourceGroupName,
        Parameters.privateZoneName,
        Parameters.subscriptionId
    ],
    queryParameters: [
        Parameters.apiVersion
    ],
    headerParameters: [
        Parameters.ifMatch,
        Parameters.acceptLanguage
    ],
    responses: {
        200: {},
        202: {},
        204: {},
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PrivateZoneListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
var listByResourceGroupNextOperationSpec = {
    httpMethod: "GET",
    baseUrl: "https://management.azure.com",
    path: "{nextLink}",
    urlParameters: [
        Parameters.nextPageLink
    ],
    headerParameters: [
        Parameters.acceptLanguage
    ],
    responses: {
        200: {
            bodyMapper: Mappers.PrivateZoneListResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    serializer: serializer
};
//# sourceMappingURL=privateZones.js.map