/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is
 * regenerated.
 */

import * as msRest from "@azure/ms-rest-js";
import * as Models from "../models";
import * as Mappers from "../models/queueMappers";
import * as Parameters from "../models/parameters";
import { StorageManagementClientContext } from "../storageManagementClientContext";

/** Class representing a Queue. */
export class Queue {
  private readonly client: StorageManagementClientContext;

  /**
   * Create a Queue.
   * @param {StorageManagementClientContext} client Reference to the service client.
   */
  constructor(client: StorageManagementClientContext) {
    this.client = client;
  }

  /**
   * Creates a new queue with the specified queue name, under the specified account.
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param queueName A queue name must be unique within a storage account and must be between 3 and
   * 63 characters.The name must comprise of lowercase alphanumeric and dash(-) characters only, it
   * should begin and end with an alphanumeric character and it cannot have two consecutive dash(-)
   * characters.
   * @param [options] The optional parameters
   * @returns Promise<Models.QueueCreateResponse>
   */
  create(resourceGroupName: string, accountName: string, queueName: string, options?: Models.QueueCreateOptionalParams): Promise<Models.QueueCreateResponse>;
  /**
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param queueName A queue name must be unique within a storage account and must be between 3 and
   * 63 characters.The name must comprise of lowercase alphanumeric and dash(-) characters only, it
   * should begin and end with an alphanumeric character and it cannot have two consecutive dash(-)
   * characters.
   * @param callback The callback
   */
  create(resourceGroupName: string, accountName: string, queueName: string, callback: msRest.ServiceCallback<Models.StorageQueue>): void;
  /**
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param queueName A queue name must be unique within a storage account and must be between 3 and
   * 63 characters.The name must comprise of lowercase alphanumeric and dash(-) characters only, it
   * should begin and end with an alphanumeric character and it cannot have two consecutive dash(-)
   * characters.
   * @param options The optional parameters
   * @param callback The callback
   */
  create(resourceGroupName: string, accountName: string, queueName: string, options: Models.QueueCreateOptionalParams, callback: msRest.ServiceCallback<Models.StorageQueue>): void;
  create(resourceGroupName: string, accountName: string, queueName: string, options?: Models.QueueCreateOptionalParams | msRest.ServiceCallback<Models.StorageQueue>, callback?: msRest.ServiceCallback<Models.StorageQueue>): Promise<Models.QueueCreateResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        accountName,
        queueName,
        options
      },
      createOperationSpec,
      callback) as Promise<Models.QueueCreateResponse>;
  }

  /**
   * Creates a new queue with the specified queue name, under the specified account.
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param queueName A queue name must be unique within a storage account and must be between 3 and
   * 63 characters.The name must comprise of lowercase alphanumeric and dash(-) characters only, it
   * should begin and end with an alphanumeric character and it cannot have two consecutive dash(-)
   * characters.
   * @param [options] The optional parameters
   * @returns Promise<Models.QueueUpdateResponse>
   */
  update(resourceGroupName: string, accountName: string, queueName: string, options?: Models.QueueUpdateOptionalParams): Promise<Models.QueueUpdateResponse>;
  /**
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param queueName A queue name must be unique within a storage account and must be between 3 and
   * 63 characters.The name must comprise of lowercase alphanumeric and dash(-) characters only, it
   * should begin and end with an alphanumeric character and it cannot have two consecutive dash(-)
   * characters.
   * @param callback The callback
   */
  update(resourceGroupName: string, accountName: string, queueName: string, callback: msRest.ServiceCallback<Models.StorageQueue>): void;
  /**
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param queueName A queue name must be unique within a storage account and must be between 3 and
   * 63 characters.The name must comprise of lowercase alphanumeric and dash(-) characters only, it
   * should begin and end with an alphanumeric character and it cannot have two consecutive dash(-)
   * characters.
   * @param options The optional parameters
   * @param callback The callback
   */
  update(resourceGroupName: string, accountName: string, queueName: string, options: Models.QueueUpdateOptionalParams, callback: msRest.ServiceCallback<Models.StorageQueue>): void;
  update(resourceGroupName: string, accountName: string, queueName: string, options?: Models.QueueUpdateOptionalParams | msRest.ServiceCallback<Models.StorageQueue>, callback?: msRest.ServiceCallback<Models.StorageQueue>): Promise<Models.QueueUpdateResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        accountName,
        queueName,
        options
      },
      updateOperationSpec,
      callback) as Promise<Models.QueueUpdateResponse>;
  }

  /**
   * Gets the queue with the specified queue name, under the specified account if it exists.
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param queueName A queue name must be unique within a storage account and must be between 3 and
   * 63 characters.The name must comprise of lowercase alphanumeric and dash(-) characters only, it
   * should begin and end with an alphanumeric character and it cannot have two consecutive dash(-)
   * characters.
   * @param [options] The optional parameters
   * @returns Promise<Models.QueueGetResponse>
   */
  get(resourceGroupName: string, accountName: string, queueName: string, options?: msRest.RequestOptionsBase): Promise<Models.QueueGetResponse>;
  /**
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param queueName A queue name must be unique within a storage account and must be between 3 and
   * 63 characters.The name must comprise of lowercase alphanumeric and dash(-) characters only, it
   * should begin and end with an alphanumeric character and it cannot have two consecutive dash(-)
   * characters.
   * @param callback The callback
   */
  get(resourceGroupName: string, accountName: string, queueName: string, callback: msRest.ServiceCallback<Models.StorageQueue>): void;
  /**
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param queueName A queue name must be unique within a storage account and must be between 3 and
   * 63 characters.The name must comprise of lowercase alphanumeric and dash(-) characters only, it
   * should begin and end with an alphanumeric character and it cannot have two consecutive dash(-)
   * characters.
   * @param options The optional parameters
   * @param callback The callback
   */
  get(resourceGroupName: string, accountName: string, queueName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<Models.StorageQueue>): void;
  get(resourceGroupName: string, accountName: string, queueName: string, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<Models.StorageQueue>, callback?: msRest.ServiceCallback<Models.StorageQueue>): Promise<Models.QueueGetResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        accountName,
        queueName,
        options
      },
      getOperationSpec,
      callback) as Promise<Models.QueueGetResponse>;
  }

  /**
   * Deletes the queue with the specified queue name, under the specified account if it exists.
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param queueName A queue name must be unique within a storage account and must be between 3 and
   * 63 characters.The name must comprise of lowercase alphanumeric and dash(-) characters only, it
   * should begin and end with an alphanumeric character and it cannot have two consecutive dash(-)
   * characters.
   * @param [options] The optional parameters
   * @returns Promise<msRest.RestResponse>
   */
  deleteMethod(resourceGroupName: string, accountName: string, queueName: string, options?: msRest.RequestOptionsBase): Promise<msRest.RestResponse>;
  /**
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param queueName A queue name must be unique within a storage account and must be between 3 and
   * 63 characters.The name must comprise of lowercase alphanumeric and dash(-) characters only, it
   * should begin and end with an alphanumeric character and it cannot have two consecutive dash(-)
   * characters.
   * @param callback The callback
   */
  deleteMethod(resourceGroupName: string, accountName: string, queueName: string, callback: msRest.ServiceCallback<void>): void;
  /**
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param queueName A queue name must be unique within a storage account and must be between 3 and
   * 63 characters.The name must comprise of lowercase alphanumeric and dash(-) characters only, it
   * should begin and end with an alphanumeric character and it cannot have two consecutive dash(-)
   * characters.
   * @param options The optional parameters
   * @param callback The callback
   */
  deleteMethod(resourceGroupName: string, accountName: string, queueName: string, options: msRest.RequestOptionsBase, callback: msRest.ServiceCallback<void>): void;
  deleteMethod(resourceGroupName: string, accountName: string, queueName: string, options?: msRest.RequestOptionsBase | msRest.ServiceCallback<void>, callback?: msRest.ServiceCallback<void>): Promise<msRest.RestResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        accountName,
        queueName,
        options
      },
      deleteMethodOperationSpec,
      callback);
  }

  /**
   * Gets a list of all the queues under the specified storage account
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param [options] The optional parameters
   * @returns Promise<Models.QueueListResponse>
   */
  list(resourceGroupName: string, accountName: string, options?: Models.QueueListOptionalParams): Promise<Models.QueueListResponse>;
  /**
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param callback The callback
   */
  list(resourceGroupName: string, accountName: string, callback: msRest.ServiceCallback<Models.ListQueueResource>): void;
  /**
   * @param resourceGroupName The name of the resource group within the user's subscription. The name
   * is case insensitive.
   * @param accountName The name of the storage account within the specified resource group. Storage
   * account names must be between 3 and 24 characters in length and use numbers and lower-case
   * letters only.
   * @param options The optional parameters
   * @param callback The callback
   */
  list(resourceGroupName: string, accountName: string, options: Models.QueueListOptionalParams, callback: msRest.ServiceCallback<Models.ListQueueResource>): void;
  list(resourceGroupName: string, accountName: string, options?: Models.QueueListOptionalParams | msRest.ServiceCallback<Models.ListQueueResource>, callback?: msRest.ServiceCallback<Models.ListQueueResource>): Promise<Models.QueueListResponse> {
    return this.client.sendOperationRequest(
      {
        resourceGroupName,
        accountName,
        options
      },
      listOperationSpec,
      callback) as Promise<Models.QueueListResponse>;
  }

  /**
   * Gets a list of all the queues under the specified storage account
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param [options] The optional parameters
   * @returns Promise<Models.QueueListNextResponse>
   */
  listNext(nextPageLink: string, options?: Models.QueueListNextOptionalParams): Promise<Models.QueueListNextResponse>;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param callback The callback
   */
  listNext(nextPageLink: string, callback: msRest.ServiceCallback<Models.ListQueueResource>): void;
  /**
   * @param nextPageLink The NextLink from the previous successful call to List operation.
   * @param options The optional parameters
   * @param callback The callback
   */
  listNext(nextPageLink: string, options: Models.QueueListNextOptionalParams, callback: msRest.ServiceCallback<Models.ListQueueResource>): void;
  listNext(nextPageLink: string, options?: Models.QueueListNextOptionalParams | msRest.ServiceCallback<Models.ListQueueResource>, callback?: msRest.ServiceCallback<Models.ListQueueResource>): Promise<Models.QueueListNextResponse> {
    return this.client.sendOperationRequest(
      {
        nextPageLink,
        options
      },
      listNextOperationSpec,
      callback) as Promise<Models.QueueListNextResponse>;
  }
}

// Operation Specifications
const serializer = new msRest.Serializer(Mappers);
const createOperationSpec: msRest.OperationSpec = {
  httpMethod: "PUT",
  path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Storage/storageAccounts/{accountName}/queueServices/default/queues/{queueName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.accountName,
    Parameters.subscriptionId,
    Parameters.queueName
  ],
  queryParameters: [
    Parameters.apiVersion
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  requestBody: {
    parameterPath: {
      metadata: [
        "options",
        "metadata"
      ]
    },
    mapper: {
      ...Mappers.StorageQueue,
      required: true
    }
  },
  responses: {
    200: {
      bodyMapper: Mappers.StorageQueue
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const updateOperationSpec: msRest.OperationSpec = {
  httpMethod: "PATCH",
  path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Storage/storageAccounts/{accountName}/queueServices/default/queues/{queueName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.accountName,
    Parameters.subscriptionId,
    Parameters.queueName
  ],
  queryParameters: [
    Parameters.apiVersion
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  requestBody: {
    parameterPath: {
      metadata: [
        "options",
        "metadata"
      ]
    },
    mapper: {
      ...Mappers.StorageQueue,
      required: true
    }
  },
  responses: {
    200: {
      bodyMapper: Mappers.StorageQueue
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const getOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Storage/storageAccounts/{accountName}/queueServices/default/queues/{queueName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.accountName,
    Parameters.subscriptionId,
    Parameters.queueName
  ],
  queryParameters: [
    Parameters.apiVersion
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.StorageQueue
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const deleteMethodOperationSpec: msRest.OperationSpec = {
  httpMethod: "DELETE",
  path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Storage/storageAccounts/{accountName}/queueServices/default/queues/{queueName}",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.accountName,
    Parameters.subscriptionId,
    Parameters.queueName
  ],
  queryParameters: [
    Parameters.apiVersion
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    204: {},
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  path: "subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Storage/storageAccounts/{accountName}/queueServices/default/queues",
  urlParameters: [
    Parameters.resourceGroupName,
    Parameters.accountName,
    Parameters.subscriptionId
  ],
  queryParameters: [
    Parameters.apiVersion,
    Parameters.maxpagesize,
    Parameters.filter
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.ListQueueResource
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};

const listNextOperationSpec: msRest.OperationSpec = {
  httpMethod: "GET",
  baseUrl: "https://management.azure.com",
  path: "{nextLink}",
  urlParameters: [
    Parameters.nextPageLink
  ],
  queryParameters: [
    Parameters.apiVersion,
    Parameters.maxpagesize,
    Parameters.filter
  ],
  headerParameters: [
    Parameters.acceptLanguage
  ],
  responses: {
    200: {
      bodyMapper: Mappers.ListQueueResource
    },
    default: {
      bodyMapper: Mappers.CloudError
    }
  },
  serializer
};
